pub enum PciConfigAccessType {
Type0,
Type1,
}Expand description
Represents the type of PCI configuration space access.
Variants
Type0
Type 0 PCI configuration space access. Type 0 accesses have been fully routed to the target bus number.
Type1
Type 1 PCI configuration space access. Type 1 accesses have not been fully routed to the target bus number.