ByteEnabledDwordWrite

Struct ByteEnabledDwordWrite 

pub struct ByteEnabledDwordWrite { /* private fields */ }
A DWORD value with byte enables for PCI configuration space write.

Implementations

Source

impl ByteEnabledDwordWrite

pub const fn new(value: u32, byte_enable: PciConfigByteEnable) -> Self

Create a byte-enabled DWORD value.

pub const fn with_all_bytes_enabled(value: u32) -> Self

Create a full-DWORD value with all byte lanes enabled.

pub fn from_intercept_buffer( byte_enable: PciConfigByteEnable, buffer: &[u8], ) -> Self

Create a byte-enabled DWORD value from a slice of bytes.

pub fn as_valid_byte_slice(&self) -> &[u8]

Retrieve a mutable slice of the enabled byte lanes of the DWORD.

pub const fn is_full(self) -> bool

Returns true if all byte lanes are enabled.

pub const fn byte_enable(&self) -> PciConfigByteEnable

Retrieve the underlying byte enable.

pub const fn valid_mask(self) -> u32

Get the mask of valid bytes.

pub const fn merge(self, current_value: u32) -> u32

Merge enabled byte lanes from this value into current_value.

pub const fn merge_into(self, current_value: &mut u32)

Merge enabled byte lanes from this value into current_value (read-modify-write).

pub const fn merge_low(self, current_value: u16) -> u16

Merge enabled byte lanes from the low WORD of this value into current_value.

pub const fn merge_high(self, current_value: u16) -> u16

Merge enabled byte lanes from the high WORD of this value into current_value.

pub const fn extract(self) -> u32

Keep only enabled byte lanes from this value.

pub const fn extract_low(self) -> u16

Keep only enabled byte lanes from the low WORD this value.

pub const fn extract_high(self) -> u16

Keep only enabled byte lanes from the high WORD this value.