PciConfigByteEnable

Struct PciConfigByteEnable 

pub struct PciConfigByteEnable(/* private fields */);
Byte enables for the four lanes of a PCI configuration DWORD.

Implementations

Source

impl PciConfigByteEnable

pub const FULL: Self

All byte lanes enabled.

pub const BYTE0: Self

Byte lane 0 enabled.

pub const BYTE1: Self

Byte lane 1 enabled.

pub const BYTE2: Self

Byte lane 2 enabled.

pub const BYTE3: Self

Byte lane 3 enabled.

pub const LOW_WORD: Self

Low word byte lanes enabled.

pub const HIGH_WORD: Self

High word byte lanes enabled.

pub const fn new(bits: u8) -> Option<Self>

Create byte enables from raw lane bits.

pub const fn from_offset_len(offset: u16, len: usize) -> Result<Self, IoError>

Create byte enables for an access at offset with byte length len.

pub const fn to_byte_offset_len(self) -> (u16, usize)

Returns the byte offset of the first enabled byte in the DWORD and the number of enabled bytes.

pub const fn bits(self) -> u8

Raw byte-lane bits.

pub const fn is_full(self) -> bool

Returns true if all byte lanes are enabled.

pub const fn mask(self) -> u32

u32 mask corresponding to the enabled byte lanes.

pub const fn merge(self, current_value: u32, write_value: u32) -> u32

Merge enabled byte lanes from write_value into current_value.

pub const fn extract(self, value: u32) -> u32

Keep only enabled byte lanes from value.

pub const fn restrict(self, byte_enable: PciConfigByteEnable) -> Option<Self>

Restrict the underlying byte enable to only include the provided bytes, or None when no bytes would be left enabled.

pub const fn exclude(self, byte_enable: PciConfigByteEnable) -> Option<Self>

Exclude the provided bytes from the underlying byte enable, returning None when no bytes would be left enabled.