RamDiskLayerHandle

Struct RamDiskLayerHandle 

pub struct RamDiskLayerHandle {
    pub len: Option<u64>,
    pub sector_size: Option<u32>,
}
RAM disk layer handle.

FUTURE: allocate shared memory here so that the disk can be migrated between processes.

Fields

len: Option<u64>

The size of the layer. If None, the layer will be the same size as the lower disk.

sector_size: Option<u32>

The sector size in bytes. If None, uses the lower layer’s sector size, or 512 if there is no lower layer.