ram_disk_with_sector_size

Function ram_disk_with_sector_size 

pub fn ram_disk_with_sector_size(
    size: u64,
    read_only: bool,
    sector_size: u32,
) -> Result<Disk>
Create a RAM disk of size bytes with the given sector size.

This is a convenience function for creating a layered disk with a single RAM layer and a custom sector size.