pub struct SignaturesReplace {
pub pk: SignatureDelta,
pub kek: SignatureDeltaVec,
pub db: SignatureDeltaVec,
pub dbx: SignatureDeltaVec,
pub moklist: Option<SignatureDeltaVec>,
pub moklistx: Option<SignatureDeltaVec>,
}Expand description
Replace the underlying template signatures, optionally using Default values
from a base template. If no base template is provided, all required signature
values must be specified explicitly.
Fields
pk: SignatureDeltakek: SignatureDeltaVecdb: SignatureDeltaVecdbx: SignatureDeltaVecmoklist: Option<SignatureDeltaVec>moklistx: Option<SignatureDeltaVec>Trait Implementations
Sourceimpl Clone for SignaturesReplace
impl Clone for SignaturesReplace
Sourcefn clone(&self) -> SignaturesReplace
fn clone(&self) -> SignaturesReplace
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SignaturesReplace
impl RefUnwindSafe for SignaturesReplace
impl Send for SignaturesReplace
impl Sync for SignaturesReplace
impl Unpin for SignaturesReplace
impl UnsafeUnpin for SignaturesReplace
impl UnwindSafe for SignaturesReplace