pub struct UefiVars {
pub signatures: Option<Signatures>,
pub non_signature_vars: Vec<(String, UefiVar)>,
}Expand description
Collection of UEFI nvram variables that will be injected on first boot.
Fields
signatures: Option<Signatures>Secure Boot signature vars
non_signature_vars: Vec<(String, UefiVar)>UEFI vars that are not Secure Boot signature vars
Implementations
Sourceimpl UefiVars
impl UefiVars
Sourcepub fn apply_delta(
self,
delta: UefiVarsDelta,
) -> Result<UefiVars, ApplyDeltaError>
pub fn apply_delta( self, delta: UefiVarsDelta, ) -> Result<UefiVars, ApplyDeltaError>
Apply a delta on top of an existing set of UEFI variables.