pub struct ResolvedUefiWatchdogPlatform {
pub platform: Box<dyn WatchdogPlatform>,
pub watchdog_recv: Receiver<()>,
}Expand description
Resolved UEFI watchdog platform, including the receiver used by the device to wake up on watchdog timeout notifications.
Fields
platform: Box<dyn WatchdogPlatform>watchdog_recv: Receiver<()>Trait Implementations
Sourceimpl CanResolveTo<ResolvedUefiWatchdogPlatform> for UefiWatchdogPlatformHandleKind
impl CanResolveTo<ResolvedUefiWatchdogPlatform> for UefiWatchdogPlatformHandleKind