shell_cmd

Macro shell_cmd 

macro_rules! shell_cmd {
    ($rt:expr, $cmd:literal) => { ... };
}
Construct a command to run via the flowey shell.

This is a thin wrapper around [xshell::cmd!] that abstracts the underlying shell implementation, making it possible to swap in a different shell backend in the future (e.g. wrapping commands in nix-shell --pure) without touching every callsite.

Example

flowey::shell_cmd!(rt, "cargo build --release").run()?;