CcaTestsCli

Struct CcaTestsCli 

pub struct CcaTestsCli {
    pub test_root: PathBuf,
    pub install_emu: bool,
    pub update_emu: bool,
    pub verbose: bool,
    pub update_emu_subcmds: CcaTestsUpdateEmuSubCmds,
}
CCA test flows, including installing, updating CCA emulation environment and run OpenVMM tests

Fields

test_root: PathBuf

Root directory for holding all CCA test related stuff

install_emu: bool

Install CCA emulation environment, including downloading emulator and building all needed firmware

update_emu: bool

Update CCA emulation environment by rebuilding firmwares, support a few sub-commands

verbose: bool

Verbose pipeline output

update_emu_subcmds: CcaTestsUpdateEmuSubCmds