group_by

Function group_by 

pub fn group_by<K: Ord, V>(
    items: impl IntoIterator<Item = (K, V)>,
) -> BTreeMap<K, Vec<V>>
Group values by key, ordering groups deterministically and retaining all values within each group in input order.