pub struct Config {
pub auto_install: Option<bool>,
pub ignore_version: Option<bool>,
pub version: Option<String>,
}Expand description
Config for the install_rust node.
Fields
auto_install: Option<bool>Automatically install all required Rust tools and components.
If false - will check for pre-existing Rust installation, and fail if it doesn’t meet the current job’s requirements.
ignore_version: Option<bool>Ignore the Version requirement, and build using whatever version of the Rust toolchain the user has installed locally.
version: Option<String>Install a specific Rust toolchain version.