Request

Struct Request 

pub struct Request {
    pub test_results: ReadVar<TestResults>,
    pub test_label: String,
    pub attachments: BTreeMap<String, (ReadVar<PathBuf>, bool)>,
    pub output_dir: Option<ReadVar<PathBuf>>,
    pub upload_logs_on_success: bool,
    pub done: WriteVar<SideEffect>,
}

Fields

test_results: ReadVar<TestResults>

Contains whether all passed and the path to a junit.xml file

HACK: this is an optional since flowey doesn’t (yet?) have any way to perform conditional-requests, and there are instances where nodes will only conditionally output JUnit XML.

To keep making forward progress, I’ve tweaked this node to accept an optional… but this ain’t great.

test_label: String

Brief string used when publishing the test. Must be unique to the pipeline.

attachments: BTreeMap<String, (ReadVar<PathBuf>, bool)>

Additional files or directories to upload.

The boolean indicates whether the attachment is referenced in the JUnit XML file. On backends with native JUnit attachment support, these attachments will not be uploaded as distinct artifacts and will instead be uploaded via the JUnit integration.

output_dir: Option<ReadVar<PathBuf>>

Copy the xml file and attachments to the provided directory. Only supported on local backend.

upload_logs_on_success: bool

Upload logs on success (logs are always uploaded on failure)

done: WriteVar<SideEffect>

Side-effect confirming that the publish has succeeded