pub struct Config {
pub fail_fast: Option<bool>,
pub terminate_job_on_fail: Option<bool>,
}Expand description
Config for the run_cargo_nextest_run node.
Fields
fail_fast: Option<bool>Set the default nextest fast fail behavior. Defaults to not fast-failing when a single test fails.
terminate_job_on_fail: Option<bool>Set the default behavior when a test failure is encountered. Defaults to not terminating the job when a single test fails.