BuildNextestUnitTestMode

Enum BuildNextestUnitTestMode 

pub enum BuildNextestUnitTestMode {
    ImmediatelyRun {
        nextest_profile: NextestProfile,
        junit_test_label: String,
        artifact_dir: Option<ReadVar<PathBuf>>,
        results: WriteVar<Vec<TestResults>>,
        publish_done: WriteVar<SideEffect>,
    },
    Archive(WriteVar<Vec<NextestUnitTestArchive>>),
}
Build mode to use when building the nextest unit tests

Variants



ImmediatelyRun

Build, immediately run, and publish unit test results, side-stepping any intermediate archiving steps.

Fields

nextest_profile: NextestProfile
junit_test_label: String

Friendly label prefix used when publishing JUnit results. Each run is published with this prefix combined with the run’s friendly name to ensure uniqueness within the pipeline.

artifact_dir: Option<ReadVar<PathBuf>>

If provided, also copy the published junit.xml files into this directory (only honored on local backends).

results: WriteVar<Vec<TestResults>>

Per-run test results, in the same order produced internally.

publish_done: WriteVar<SideEffect>

Signaled once every run’s junit.xml has been published.



Archive(WriteVar<Vec<NextestUnitTestArchive>>)

Build and archive the tests into nextest archive files, which can then be run via crate::test_nextest_unit_tests_archive.