pub struct Request {
pub build_profile: OpenvmmHclBuildProfile,
pub release_cfg: bool,
pub recipe: OpenhclIgvmRecipeType,
pub custom_target: Option<CommonTriple>,
pub extra_features: BTreeSet<OpenvmmHclFeature>,
pub disable_secure_avic: bool,
pub confidential_debug: bool,
pub openhcl_igvm: WriteVar<OpenhclIgvmOutput>,
pub openhcl_igvm_extras: WriteVar<OpenhclIgvmExtrasOutput>,
}Fields
build_profile: OpenvmmHclBuildProfilerelease_cfg: boolrecipe: OpenhclIgvmRecipeTypecustom_target: Option<CommonTriple>extra_features: BTreeSet<OpenvmmHclFeature>Additional features to enable on top of the recipe’s defaults.
disable_secure_avic: boolconfidential_debug: boolAdd the confidential debug flag to the measured OpenHCL command line, enabling confidential diagnostics on CVM builds.
openhcl_igvm: WriteVar<OpenhclIgvmOutput>openhcl_igvm_extras: WriteVar<OpenhclIgvmExtrasOutput>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Request
impl<'de> Deserialize<'de> for Request
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more