pub struct Request {
pub test_content_dir: ReadVar<PathBuf>,
pub vmm_tests_target: Triple,
pub built_artifacts: VmmTestsBuiltArtifacts,
pub is_repo_root: bool,
pub needs_release_igvm: bool,
pub needs_incubator_profiles: bool,
pub done: WriteVar<SideEffect>,
}Fields
test_content_dir: ReadVar<PathBuf>Directory to symlink / copy test contents into. Does not need to be empty.
vmm_tests_target: TripleWhat triple VMM tests are built for.
Used to detect cases of running Windows VMM tests via WSL2, and adjusting reported paths appropriately.
built_artifacts: VmmTestsBuiltArtifactsArtifacts used by the tests that are built in the openvmm repo
is_repo_root: boolCopy files necessary to use the test content dir as a minimal repo root.
This is useful for running tests on machines without a local clone.
needs_release_igvm: boolWhether the tests require that release igvm files are downloaded
needs_incubator_profiles: boolWhether to copy incubator profiles into the test content directory.
done: WriteVar<SideEffect>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Request
impl<'de> Deserialize<'de> for Request
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more