pub struct Request {
pub test_content_dir: ReadVar<PathBuf>,
pub disk_images_dir: Option<ReadVar<PathBuf>>,
pub vmm_tests_target: Triple,
pub get_test_log_path: Option<WriteVar<PathBuf>>,
pub petri_params: PetriParams,
pub get_env: WriteVar<BTreeMap<String, String>>,
}Fields
test_content_dir: ReadVar<PathBuf>Directory to symlink / copy test contents into. Does not need to be empty.
disk_images_dir: Option<ReadVar<PathBuf>>Specify where VMM tests disk images are stored.
vmm_tests_target: TripleWhat triple VMM tests are built for.
Used to detect cases of running Windows VMM tests via WSL2, and adjusting reported paths appropriately.
get_test_log_path: Option<WriteVar<PathBuf>>Get the path to the folder containing various logs emitted VMM tests.
petri_params: PetriParamsParameters to pass to Petri via environment variables
get_env: WriteVar<BTreeMap<String, String>>Get a map of env vars required to be set when running VMM tests