pub enum LinuxTestKernelVersion {
Linux6_1,
}Expand description
Which Linux test kernel version to fetch from the openvmm-deps GitHub release.
The openvmm-deps release currently only ships the 6.1 kernel; additional
kernel lines (e.g. 6.6, 6.12) are intended to be added as purely additive
follow-ups, both upstream and as new variants of this enum.
Variants
Linux6_1
Implementations
Sourceimpl LinuxTestKernelVersion
impl LinuxTestKernelVersion
Sourcepub fn artifact_tag(self) -> &'static str
pub fn artifact_tag(self) -> &'static str
The version string used in the openvmm-deps GitHub release artifact
filename (e.g. "6.1" for openvmm-test-linux-6.1.<arch>.<ver>.tar.gz).