pub struct RsiRealmConfig { /* private fields */ }Expand description
Representation of the Realm config data available to Plane 0.
- ipa_width is the size of the realm protected memory space
- hash_algo is the hash alg used for measurements
- num_aux_planes indicates how many low-privilege planes exist
- gicv3_vtr shows part of the GICv3 configuration for the realm, needed for GIC virtualisation
Implementations