pub struct HvInterruptControl(/* private fields */);Expand description
The declaration uses the fact the bits for the different
architectures don’t intersect. When (if ever) they do,
will need to come up with a more elaborate abstraction.
The other possible downside is the lack of the compile-time
checks as adding that will require guest_arch support and
a large refactoring. To sum up, choosing expediency.
Implementations
Sourceimpl HvInterruptControl
impl HvInterruptControl
Sourcepub const fn x86_level_triggered(&self) -> bool
pub const fn x86_level_triggered(&self) -> bool
Bits: 32..33
Sourcepub const fn with_x86_level_triggered_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_x86_level_triggered_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 32..33
Sourcepub const fn with_x86_level_triggered(self, value: bool) -> Self
pub const fn with_x86_level_triggered(self, value: bool) -> Self
Bits: 32..33
Sourcepub const fn set_x86_level_triggered(&mut self, value: bool)
pub const fn set_x86_level_triggered(&mut self, value: bool)
Bits: 32..33
Sourcepub const fn set_x86_level_triggered_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_x86_level_triggered_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 32..33
Sourcepub const fn x86_logical_destination_mode(&self) -> bool
pub const fn x86_logical_destination_mode(&self) -> bool
Bits: 33..34
Sourcepub const fn with_x86_logical_destination_mode_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_x86_logical_destination_mode_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 33..34
Sourcepub const fn with_x86_logical_destination_mode(self, value: bool) -> Self
pub const fn with_x86_logical_destination_mode(self, value: bool) -> Self
Bits: 33..34
Sourcepub const fn set_x86_logical_destination_mode(&mut self, value: bool)
pub const fn set_x86_logical_destination_mode(&mut self, value: bool)
Bits: 33..34
Sourcepub const fn set_x86_logical_destination_mode_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_x86_logical_destination_mode_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 33..34
Sourcepub const fn arm64_asserted(&self) -> bool
pub const fn arm64_asserted(&self) -> bool
Bits: 34..35
Sourcepub const fn with_arm64_asserted_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_arm64_asserted_checked(self, value: bool) -> Result<Self, ()>
Bits: 34..35
Sourcepub const fn with_arm64_asserted(self, value: bool) -> Self
pub const fn with_arm64_asserted(self, value: bool) -> Self
Bits: 34..35
Sourcepub const fn set_arm64_asserted(&mut self, value: bool)
pub const fn set_arm64_asserted(&mut self, value: bool)
Bits: 34..35
Sourcepub const fn set_arm64_asserted_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_arm64_asserted_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 34..35
Sourcepub const fn with_unused_checked(self, value: u32) -> Result<Self, ()>
pub const fn with_unused_checked(self, value: u32) -> Result<Self, ()>
Bits: 35..64
Sourcepub const fn with_unused(self, value: u32) -> Self
pub const fn with_unused(self, value: u32) -> Self
Bits: 35..64
Sourcepub const fn set_unused(&mut self, value: u32)
pub const fn set_unused(&mut self, value: u32)
Bits: 35..64
Sourceimpl HvInterruptControl
impl HvInterruptControl
pub fn interrupt_type(&self) -> HvInterruptType
pub fn set_interrupt_type(&mut self, ty: HvInterruptType)
pub fn with_interrupt_type(self, ty: HvInterruptType) -> Self