isolation_short_name

Function isolation_short_name 

pub fn isolation_short_name(platform: IgvmPlatformType) -> Option<&'static str>
Short lowercase name for a measurable platform, suitable for file names and CLI suffixes (e.g. "snp", "tdx", "vbs").

Returns None for platform variants that don’t have a canonical short name in this tool (e.g. Native).