compute_variable_mtrrs

Function compute_variable_mtrrs 

pub fn compute_variable_mtrrs(
    memory: &MemoryLayout,
    physical_address_width: u8,
    chipset_low_mmio: MemoryRange,
    chipset_high_mmio: MemoryRange,
) -> Vec<X86Register>
Computes the x86 variable MTRRs that describe the given memory layout. This is intended to be used to setup MTRRs for booting a guest with two mmio gaps, such as booting Linux, UEFI, or PCAT.