load

Function load 

pub fn load(
    importer: &mut dyn ImageLoad<Aarch64Register>,
    image: &[u8],
    config: ConfigType,
    hv_enabled: bool,
) -> Result<LoadInfo, Error>
Load a UEFI image with the provided config type.

hv_enabled selects the SEC platform type passed to the firmware in x2: Hyper-V when enlightenments are exposed, or generic when they are not.