#[repr(C)]pub struct PersistedStateHeader {
pub magic: u64,
pub protobuf_base: u64,
pub protobuf_region_len: u64,
pub protobuf_payload_len: u64,
}Expand description
This is the header used to describe the overall persisted state region. By convention, the header resides at the start of VTL2 memory, taking a single page.
This header should never change, instead for new information to be stored add it to the protobuf payload described below.
Fields
magic: u64A magic value. If this is not set to PersistedStateHeader::MAGIC,
then the previous instance did not support this region.
protobuf_base: u64The gpa for the start of the protobuf region. This must be 4K aligned.
protobuf_region_len: u64The size of the protobuf region in bytes.
protobuf_payload_len: u64The size of the protobuf payload in bytes.
This must be less than or equal to protobuf_region_len.
Implementations