Vport

Struct Vport 

pub struct Vport<T: DeviceBacking> { /* private fields */ }
A MANA vport.

Implementations

Source

impl<T: DeviceBacking> Vport<T>

pub fn max_tx_queues(&self) -> u32

Returns the maximum number of transmit queues.

pub fn max_rx_queues(&self) -> u32

Returns the maximum number of receive queues.

pub fn mac_address(&self) -> MacAddress

Returns the assigned MAC address.

pub fn gpa_mkey(&self) -> u32

Returns the memory key to refer to all of GPA space.

pub fn id(&self) -> u32

Returns this vport’s id

pub fn num_indirection_ent(&self) -> u32

Returns the number of indirection entries supported by the vport

Returns the adapter link speed in bits per second, as reported by the device configuration.

pub async fn new_eq( &self, arena: &mut ResourceArena, size: u32, cpu: u32, ) -> Result<BnicEq>

Creates a new event queue.

pub async fn new_wq( &self, arena: &mut ResourceArena, is_send: bool, wq_size: u32, cq_size: u32, eq_id: u32, ) -> Result<BnicWq>

Creates a new work queue (transmit or receive).

pub async fn config_tx(&self) -> Result<TxConfig>

Get the transmit configuration.

pub async fn config_rx(&self, config: &RxConfig<'_>) -> Result<()>

Sets the receive configuration.

pub async fn move_filter(&self, direction_to_vtl0: u8) -> Result<()>

Move filter between VTL2 VF vport and VTL0 VF vport

pub async fn get_direction_to_vtl0(&self) -> Option<bool>

Get current filter state.

pub async fn set_serial_no(&self, serial_no: u32) -> Result<()>

Set the vport serial number

pub async fn query_stats(&self) -> Result<ManaQueryStatisticsResponse>

Gets stats. Note that these are adapter-wide and not really per-vport.

pub async fn query_filter_state( &self, vport: u64, ) -> Result<ManaQueryFilterStateResponse>

Retrieves vport mac filter state from socamana

pub async fn destroy(&self, arena: ResourceArena)

Destroys resources in arena.

pub async fn retarget_interrupt( &self, eq_id: u32, cpu: u32, ) -> Result<Option<DeviceInterrupt>>

Changes the target CPU for the given eq to cpu.

Registers for link status notification updates.

pub async fn dma_client(&self) -> Arc<dyn DmaClient>

Returns an object that can allocate dma memory to be shared with the device.