RamVisibilityControl

Struct RamVisibilityControl 

pub struct RamVisibilityControl { /* private fields */ }
A client to the GuestMemoryManager used to control the visibility of RAM regions.

Implementations

Source

impl RamVisibilityControl

pub async fn set_ram_visibility( &self, range: MemoryRange, visibility: RamVisibility, ) -> Result<(), RamVisibilityError>

Sets the visibility of a RAM region.

A whole region’s visibility must be controlled at once, or an error will be returned. GuestMemoryBuilder::x86_legacy_support can be used to ensure that there are RAM regions corresponding to x86 memory ranges that need to be controlled.