RxChecksumState

Enum RxChecksumState 

pub enum RxChecksumState {
    Unknown,
    Good,
    Bad,
    ValidatedButWrong,
}
The receive checksum state for a packet.

Variants



Unknown

The checksum was not evaluated.



Good

The checksum value is correct.



Bad

The checksum value is incorrect.



ValidatedButWrong

The checksum has been validated, but the value in the header is wrong.

This occurs when LRO/RSC offload has been performed–multiple packet payloads are glommed together without updating the checksum in the first packet’s header.

Implementations



impl RxChecksumState

pub fn is_valid(self) -> bool

Returns true if the checksum has been validated.