pub struct RxMetadata {
pub offset: usize,
pub len: usize,
pub ip_checksum: RxChecksumState,
pub l4_checksum: RxChecksumState,
pub l4_protocol: L4Protocol,
pub vlan: Option<VlanMetadata>,
}Expand description
Receive packet metadata.
Fields
offset: usizeThe offset of the packet data from the beginning of the receive buffer.
len: usizeThe length of the packet in bytes.
ip_checksum: RxChecksumStateThe IP checksum validation state.
l4_checksum: RxChecksumStateThe L4 checksum validation state.
l4_protocol: L4ProtocolThe L4 protocol.
vlan: Option<VlanMetadata>Information about 802.1Q VLAN tagging. When a vlan is in use, this structure is populated. Only applies when traffic is being received over an L2 connection, so L3-only or above traffic will not use this option.