pub enum HostPort {
Fixed(u16),
Dynamic(OneshotSender<u16>),
}Expand description
The host port to listen on for a port forward.
Variants
Fixed(u16)
A fixed host port.
Dynamic(OneshotSender<u16>)
Let the OS assign a port. The assigned port is sent back via the oneshot sender.