pub struct HostPortConfig {
pub protocol: HostPortProtocol,
pub host_address: Option<HostIpAddress>,
pub host_port: HostPort,
pub guest_port: u16,
}Expand description
Configuration for forwarding a host port into the guest.
Fields
protocol: HostPortProtocolThe protocol to forward.
host_address: Option<HostIpAddress>The host IP address to bind to, or None to bind to all interfaces.
host_port: HostPortThe host port to listen on.
guest_port: u16The guest port to forward to.