#[repr(C)]pub struct IdentifyController {Show 95 fields
pub vid: u16,
pub ssvid: u16,
pub sn: AsciiString<20>,
pub mn: AsciiString<40>,
pub fr: AsciiString<8>,
pub rab: u8,
pub ieee: [u8; 3],
pub cmic: u8,
pub mdts: u8,
pub cntlid: u16,
pub ver: u32,
pub rtd3r: u32,
pub rtd3e: u32,
pub oaes: Oaes,
pub ctratt: u32,
pub rrls: u16,
pub rsvd1: [u8; 9],
pub cntrltype: ControllerType,
pub fguid: [u8; 16],
pub crdt1: u16,
pub crdt2: u16,
pub crdt3: u16,
pub rsvd2: [u8; 106],
pub rsvd3: [u8; 13],
pub nvmsr: u8,
pub vwci: u8,
pub mec: u8,
pub oacs: OptionalAdminCommandSupport,
pub acl: u8,
pub aerl: u8,
pub frmw: FirmwareUpdates,
pub lpa: u8,
pub elpe: u8,
pub npss: u8,
pub avscc: u8,
pub apsta: u8,
pub wctemp: u16,
pub cctemp: u16,
pub mtfa: u16,
pub hmpre: u32,
pub hmmin: u32,
pub tnvmcap: U128<LE>,
pub unvmcap: U128<LE>,
pub rpmbs: u32,
pub edstt: u16,
pub dsto: u8,
pub fwug: u8,
pub kas: u16,
pub hctma: u16,
pub mntmt: u16,
pub mxtmt: u16,
pub sanicap: u32,
pub hmminds: u32,
pub hmmaxd: u16,
pub nsetidmax: u16,
pub endgidmax: u16,
pub anatt: u8,
pub anacap: u8,
pub anagrpmax: u32,
pub nanagrpid: u32,
pub pels: u32,
pub domain_id: u16,
pub rsvd4: [u8; 10],
pub megcap: U128<LE>,
pub rsvd5: [u8; 128],
pub sqes: QueueEntrySize,
pub cqes: QueueEntrySize,
pub maxcmd: u16,
pub nn: u32,
pub oncs: Oncs,
pub fuses: u16,
pub fna: u8,
pub vwc: VolatileWriteCache,
pub awun: u16,
pub awupf: u16,
pub icsvscc: u8,
pub nwpc: u8,
pub acwu: u16,
pub copy_descriptor_fmt: u16,
pub sgls: u32,
pub mnan: u32,
pub maxdna: U128<LE>,
pub maxcna: u32,
pub rsvd6: [u8; 204],
pub subnqn: [u8; 256],
pub rsvd7: [u8; 768],
pub ioccsz: u32,
pub iorcsz: u32,
pub icdoff: u16,
pub fcatt: u8,
pub msdbd: u8,
pub ofcs: u16,
pub rsvd8: [u8; 242],
pub power: [u8; 1024],
pub vendor: [u8; 1024],
}Fields
vid: u16ssvid: u16sn: AsciiString<20>mn: AsciiString<40>fr: AsciiString<8>rab: u8ieee: [u8; 3]cmic: u8mdts: u8Maximum data transfer size (in minimum page size units, as power of two).
cntlid: u16ver: u32rtd3r: u32rtd3e: u32oaes: Oaesctratt: u32rrls: u16rsvd1: [u8; 9]cntrltype: ControllerTypefguid: [u8; 16]crdt1: u16crdt2: u16crdt3: u16rsvd2: [u8; 106]rsvd3: [u8; 13]nvmsr: u8vwci: u8mec: u8oacs: OptionalAdminCommandSupportacl: u8aerl: u8frmw: FirmwareUpdateslpa: u8elpe: u8npss: u8avscc: u8apsta: u8wctemp: u16cctemp: u16mtfa: u16hmpre: u32hmmin: u32tnvmcap: U128<LE>unvmcap: U128<LE>rpmbs: u32edstt: u16dsto: u8fwug: u8kas: u16hctma: u16mntmt: u16mxtmt: u16sanicap: u32hmminds: u32hmmaxd: u16nsetidmax: u16endgidmax: u16anatt: u8anacap: u8anagrpmax: u32nanagrpid: u32pels: u32domain_id: u16rsvd4: [u8; 10]megcap: U128<LE>rsvd5: [u8; 128]sqes: QueueEntrySizecqes: QueueEntrySizemaxcmd: u16nn: u32oncs: Oncsfuses: u16fna: u8vwc: VolatileWriteCacheawun: u16awupf: u16icsvscc: u8nwpc: u8acwu: u16copy_descriptor_fmt: u16sgls: u32mnan: u32maxdna: U128<LE>maxcna: u32rsvd6: [u8; 204]subnqn: [u8; 256]rsvd7: [u8; 768]ioccsz: u32iorcsz: u32icdoff: u16fcatt: u8msdbd: u8ofcs: u16rsvd8: [u8; 242]power: [u8; 1024]vendor: [u8; 1024]Trait Implementations
Sourceimpl Clone for IdentifyController
impl Clone for IdentifyController
Sourcefn clone(&self) -> IdentifyController
fn clone(&self) -> IdentifyController
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentifyController
impl Debug for IdentifyController
Sourceimpl FromBytes for IdentifyControllerwhere
u16: FromBytes,
AsciiString<20>: FromBytes,
AsciiString<40>: FromBytes,
AsciiString<8>: FromBytes,
u8: FromBytes,
[u8; 3]: FromBytes,
u32: FromBytes,
Oaes: FromBytes,
[u8; 9]: FromBytes,
ControllerType: FromBytes,
[u8; 16]: FromBytes,
[u8; 106]: FromBytes,
[u8; 13]: FromBytes,
OptionalAdminCommandSupport: FromBytes,
FirmwareUpdates: FromBytes,
U128<LE>: FromBytes,
[u8; 10]: FromBytes,
[u8; 128]: FromBytes,
QueueEntrySize: FromBytes,
Oncs: FromBytes,
VolatileWriteCache: FromBytes,
[u8; 204]: FromBytes,
[u8; 256]: FromBytes,
[u8; 768]: FromBytes,
[u8; 242]: FromBytes,
[u8; 1024]: FromBytes,
impl FromBytes for IdentifyControllerwhere
u16: FromBytes,
AsciiString<20>: FromBytes,
AsciiString<40>: FromBytes,
AsciiString<8>: FromBytes,
u8: FromBytes,
[u8; 3]: FromBytes,
u32: FromBytes,
Oaes: FromBytes,
[u8; 9]: FromBytes,
ControllerType: FromBytes,
[u8; 16]: FromBytes,
[u8; 106]: FromBytes,
[u8; 13]: FromBytes,
OptionalAdminCommandSupport: FromBytes,
FirmwareUpdates: FromBytes,
U128<LE>: FromBytes,
[u8; 10]: FromBytes,
[u8; 128]: FromBytes,
QueueEntrySize: FromBytes,
Oncs: FromBytes,
VolatileWriteCache: FromBytes,
[u8; 204]: FromBytes,
[u8; 256]: FromBytes,
[u8; 768]: FromBytes,
[u8; 242]: FromBytes,
[u8; 1024]: FromBytes,
fn ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: Immutable + KnownLayout,
fn ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: Immutable + KnownLayout,
Interprets the suffix of the given bytes as a
&Self. Read morefn mut_from_bytes(
source: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_bytes(
source: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
Sourceimpl FromZeros for IdentifyControllerwhere
u16: FromZeros,
AsciiString<20>: FromZeros,
AsciiString<40>: FromZeros,
AsciiString<8>: FromZeros,
u8: FromZeros,
[u8; 3]: FromZeros,
u32: FromZeros,
Oaes: FromZeros,
[u8; 9]: FromZeros,
ControllerType: FromZeros,
[u8; 16]: FromZeros,
[u8; 106]: FromZeros,
[u8; 13]: FromZeros,
OptionalAdminCommandSupport: FromZeros,
FirmwareUpdates: FromZeros,
U128<LE>: FromZeros,
[u8; 10]: FromZeros,
[u8; 128]: FromZeros,
QueueEntrySize: FromZeros,
Oncs: FromZeros,
VolatileWriteCache: FromZeros,
[u8; 204]: FromZeros,
[u8; 256]: FromZeros,
[u8; 768]: FromZeros,
[u8; 242]: FromZeros,
[u8; 1024]: FromZeros,
impl FromZeros for IdentifyControllerwhere
u16: FromZeros,
AsciiString<20>: FromZeros,
AsciiString<40>: FromZeros,
AsciiString<8>: FromZeros,
u8: FromZeros,
[u8; 3]: FromZeros,
u32: FromZeros,
Oaes: FromZeros,
[u8; 9]: FromZeros,
ControllerType: FromZeros,
[u8; 16]: FromZeros,
[u8; 106]: FromZeros,
[u8; 13]: FromZeros,
OptionalAdminCommandSupport: FromZeros,
FirmwareUpdates: FromZeros,
U128<LE>: FromZeros,
[u8; 10]: FromZeros,
[u8; 128]: FromZeros,
QueueEntrySize: FromZeros,
Oncs: FromZeros,
VolatileWriteCache: FromZeros,
[u8; 204]: FromZeros,
[u8; 256]: FromZeros,
[u8; 768]: FromZeros,
[u8; 242]: FromZeros,
[u8; 1024]: FromZeros,
fn new_zeroed() -> Selfwhere
Self: Sized,
fn new_zeroed() -> Selfwhere
Self: Sized,
Creates an instance of
Self from zeroed bytes. Read morefn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
fn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
Creates a
Box<Self> from zeroed bytes. Read morefn new_box_zeroed_with_elems(count: usize) -> Result<Box<Self>, AllocError>where
Self: KnownLayout<PointerMetadata = usize>,
fn new_box_zeroed_with_elems(count: usize) -> Result<Box<Self>, AllocError>where
Self: KnownLayout<PointerMetadata = usize>,
Creates a
Box<[Self]> (a boxed slice) from zeroed bytes. Read morefn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
fn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
Creates a
Vec<Self> from zeroed bytes. Read moreSourceimpl Inspect for IdentifyController
impl Inspect for IdentifyController
Sourceimpl IntoBytes for IdentifyControllerwhere
u16: IntoBytes,
AsciiString<20>: IntoBytes,
AsciiString<40>: IntoBytes,
AsciiString<8>: IntoBytes,
u8: IntoBytes,
[u8; 3]: IntoBytes,
u32: IntoBytes,
Oaes: IntoBytes,
[u8; 9]: IntoBytes,
ControllerType: IntoBytes,
[u8; 16]: IntoBytes,
[u8; 106]: IntoBytes,
[u8; 13]: IntoBytes,
OptionalAdminCommandSupport: IntoBytes,
FirmwareUpdates: IntoBytes,
U128<LE>: IntoBytes,
[u8; 10]: IntoBytes,
[u8; 128]: IntoBytes,
QueueEntrySize: IntoBytes,
Oncs: IntoBytes,
VolatileWriteCache: IntoBytes,
[u8; 204]: IntoBytes,
[u8; 256]: IntoBytes,
[u8; 768]: IntoBytes,
[u8; 242]: IntoBytes,
[u8; 1024]: IntoBytes,
(): PaddingFree<Self, { _ }>,
impl IntoBytes for IdentifyControllerwhere
u16: IntoBytes,
AsciiString<20>: IntoBytes,
AsciiString<40>: IntoBytes,
AsciiString<8>: IntoBytes,
u8: IntoBytes,
[u8; 3]: IntoBytes,
u32: IntoBytes,
Oaes: IntoBytes,
[u8; 9]: IntoBytes,
ControllerType: IntoBytes,
[u8; 16]: IntoBytes,
[u8; 106]: IntoBytes,
[u8; 13]: IntoBytes,
OptionalAdminCommandSupport: IntoBytes,
FirmwareUpdates: IntoBytes,
U128<LE>: IntoBytes,
[u8; 10]: IntoBytes,
[u8; 128]: IntoBytes,
QueueEntrySize: IntoBytes,
Oncs: IntoBytes,
VolatileWriteCache: IntoBytes,
[u8; 204]: IntoBytes,
[u8; 256]: IntoBytes,
[u8; 768]: IntoBytes,
[u8; 242]: IntoBytes,
[u8; 1024]: IntoBytes,
(): PaddingFree<Self, { _ }>,
fn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
fn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
Gets the bytes of this value mutably. Read more
fn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
fn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
Sourceimpl KnownLayout for IdentifyController
impl KnownLayout for IdentifyController
Sourceimpl TryFromBytes for IdentifyControllerwhere
u16: TryFromBytes,
AsciiString<20>: TryFromBytes,
AsciiString<40>: TryFromBytes,
AsciiString<8>: TryFromBytes,
u8: TryFromBytes,
[u8; 3]: TryFromBytes,
u32: TryFromBytes,
Oaes: TryFromBytes,
[u8; 9]: TryFromBytes,
ControllerType: TryFromBytes,
[u8; 16]: TryFromBytes,
[u8; 106]: TryFromBytes,
[u8; 13]: TryFromBytes,
OptionalAdminCommandSupport: TryFromBytes,
FirmwareUpdates: TryFromBytes,
U128<LE>: TryFromBytes,
[u8; 10]: TryFromBytes,
[u8; 128]: TryFromBytes,
QueueEntrySize: TryFromBytes,
Oncs: TryFromBytes,
VolatileWriteCache: TryFromBytes,
[u8; 204]: TryFromBytes,
[u8; 256]: TryFromBytes,
[u8; 768]: TryFromBytes,
[u8; 242]: TryFromBytes,
[u8; 1024]: TryFromBytes,
impl TryFromBytes for IdentifyControllerwhere
u16: TryFromBytes,
AsciiString<20>: TryFromBytes,
AsciiString<40>: TryFromBytes,
AsciiString<8>: TryFromBytes,
u8: TryFromBytes,
[u8; 3]: TryFromBytes,
u32: TryFromBytes,
Oaes: TryFromBytes,
[u8; 9]: TryFromBytes,
ControllerType: TryFromBytes,
[u8; 16]: TryFromBytes,
[u8; 106]: TryFromBytes,
[u8; 13]: TryFromBytes,
OptionalAdminCommandSupport: TryFromBytes,
FirmwareUpdates: TryFromBytes,
U128<LE>: TryFromBytes,
[u8; 10]: TryFromBytes,
[u8; 128]: TryFromBytes,
QueueEntrySize: TryFromBytes,
Oncs: TryFromBytes,
VolatileWriteCache: TryFromBytes,
[u8; 204]: TryFromBytes,
[u8; 256]: TryFromBytes,
[u8; 768]: TryFromBytes,
[u8; 242]: TryFromBytes,
[u8; 1024]: TryFromBytes,
fn try_ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_mut_from_bytes(
bytes: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_bytes(
bytes: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
Attempts to interpret the prefix of the given
source as a &Self with
a DST length equal to count. Read morefn try_ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
Attempts to interpret the suffix of the given
source as a &Self with
a DST length equal to count. Read morefn try_mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
Attempts to interpret the prefix of the given
source as a &mut Self
with a DST length equal to count. Read morefn try_mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
Attempts to interpret the suffix of the given
source as a &mut Self
with a DST length equal to count. Read morefn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
impl Immutable for IdentifyControllerwhere
u16: Immutable,
AsciiString<20>: Immutable,
AsciiString<40>: Immutable,
AsciiString<8>: Immutable,
u8: Immutable,
[u8; 3]: Immutable,
u32: Immutable,
Oaes: Immutable,
[u8; 9]: Immutable,
ControllerType: Immutable,
[u8; 16]: Immutable,
[u8; 106]: Immutable,
[u8; 13]: Immutable,
OptionalAdminCommandSupport: Immutable,
FirmwareUpdates: Immutable,
U128<LE>: Immutable,
[u8; 10]: Immutable,
[u8; 128]: Immutable,
QueueEntrySize: Immutable,
Oncs: Immutable,
VolatileWriteCache: Immutable,
[u8; 204]: Immutable,
[u8; 256]: Immutable,
[u8; 768]: Immutable,
[u8; 242]: Immutable,
[u8; 1024]: Immutable,