LidSupportedAndEffects

Struct LidSupportedAndEffects 

pub struct LidSupportedAndEffects(/* private fields */);
LID Supported and Effects Data Structure, one per LID in the Supported Log Pages log page (LID 00h). See NVMe Base 2.3 Figure 208.

Implementations

Source

impl LidSupportedAndEffects

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u32) -> Self

Convert from bits.

pub const fn into_bits(self) -> u32

Convert into bits.

pub const fn lsupp(&self) -> bool

LID Supported

Bits: 0..1

pub const fn with_lsupp_checked(self, value: bool) -> Result<Self, ()>

LID Supported

Bits: 0..1

pub const fn with_lsupp(self, value: bool) -> Self

LID Supported

Bits: 0..1

pub const fn set_lsupp(&mut self, value: bool)

LID Supported

Bits: 0..1

pub const fn set_lsupp_checked(&mut self, value: bool) -> Result<(), ()>

LID Supported

Bits: 0..1

pub const fn ios(&self) -> bool

Index Offset Supported

Bits: 1..2

pub const fn with_ios_checked(self, value: bool) -> Result<Self, ()>

Index Offset Supported

Bits: 1..2

pub const fn with_ios(self, value: bool) -> Self

Index Offset Supported

Bits: 1..2

pub const fn set_ios(&mut self, value: bool)

Index Offset Supported

Bits: 1..2

pub const fn set_ios_checked(&mut self, value: bool) -> Result<(), ()>

Index Offset Supported

Bits: 1..2

pub const fn lidsp(&self) -> u16

LID Specific Parameter

Bits: 16..32

pub const fn with_lidsp_checked(self, value: u16) -> Result<Self, ()>

LID Specific Parameter

Bits: 16..32

pub const fn with_lidsp(self, value: u16) -> Self

LID Specific Parameter

Bits: 16..32

pub const fn set_lidsp(&mut self, value: u16)

LID Specific Parameter

Bits: 16..32

pub const fn set_lidsp_checked(&mut self, value: u16) -> Result<(), ()>

LID Specific Parameter

Bits: 16..32