pub struct IgvmCapabilityBitMap(/* private fields */);Expand description
Bitmap of additional Igvm request attributes. 0 - error_code: Requesting IGVM Agent Error code 1 - retry: Retry preference 2 - skip_hw_unsealing: Skip hardware unsealing in case key release request fails 3 - use_rsa_aes_key_wrap_384: Request that the IGVM Agent ask Azure Key Vault (AKV) to wrap and release the key with the SHA-384 variant of the composite RSA+AES key-wrap scheme (PKCS#11 CKM_RSA_AES_KEY_WRAP / AKV’s RSA_AES_KEY_WRAP_384): RSA-OAEP-SHA384 (MGF1-SHA-384) wraps an AES-256 KEK that performs AES Key Wrap on the released key. The default is the same CKM_RSA_AES_KEY_WRAP scheme with the inner RSA-OAEP using SHA-1 (MGF1-SHA-1). 4 - corim_endorsement: Request that the IGVM Agent fetch the CoRIM launch endorsement for the guest and include it in the attestation flow.
Implementations
Sourceimpl IgvmCapabilityBitMap
impl IgvmCapabilityBitMap
Sourcepub const fn error_code(&self) -> bool
pub const fn error_code(&self) -> bool
Bits: 0..1
Sourcepub const fn with_error_code_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_error_code_checked(self, value: bool) -> Result<Self, ()>
Bits: 0..1
Sourcepub const fn with_error_code(self, value: bool) -> Self
pub const fn with_error_code(self, value: bool) -> Self
Bits: 0..1
Sourcepub const fn set_error_code(&mut self, value: bool)
pub const fn set_error_code(&mut self, value: bool)
Bits: 0..1
Sourcepub const fn with_retry_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_retry_checked(self, value: bool) -> Result<Self, ()>
Bits: 1..2
Sourcepub const fn with_retry(self, value: bool) -> Self
pub const fn with_retry(self, value: bool) -> Self
Bits: 1..2
Sourcepub const fn skip_hw_unsealing(&self) -> bool
pub const fn skip_hw_unsealing(&self) -> bool
Bits: 2..3
Sourcepub const fn with_skip_hw_unsealing_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_skip_hw_unsealing_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 2..3
Sourcepub const fn with_skip_hw_unsealing(self, value: bool) -> Self
pub const fn with_skip_hw_unsealing(self, value: bool) -> Self
Bits: 2..3
Sourcepub const fn set_skip_hw_unsealing(&mut self, value: bool)
pub const fn set_skip_hw_unsealing(&mut self, value: bool)
Bits: 2..3
Sourcepub const fn set_skip_hw_unsealing_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_skip_hw_unsealing_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 2..3
Sourcepub const fn use_rsa_aes_key_wrap_384(&self) -> bool
pub const fn use_rsa_aes_key_wrap_384(&self) -> bool
Bits: 3..4
Sourcepub const fn with_use_rsa_aes_key_wrap_384_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_use_rsa_aes_key_wrap_384_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 3..4
Sourcepub const fn with_use_rsa_aes_key_wrap_384(self, value: bool) -> Self
pub const fn with_use_rsa_aes_key_wrap_384(self, value: bool) -> Self
Bits: 3..4
Sourcepub const fn set_use_rsa_aes_key_wrap_384(&mut self, value: bool)
pub const fn set_use_rsa_aes_key_wrap_384(&mut self, value: bool)
Bits: 3..4
Sourcepub const fn set_use_rsa_aes_key_wrap_384_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_use_rsa_aes_key_wrap_384_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 3..4
Sourcepub const fn corim_endorsement(&self) -> bool
pub const fn corim_endorsement(&self) -> bool
Bits: 4..5
Sourcepub const fn with_corim_endorsement_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_corim_endorsement_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 4..5
Sourcepub const fn with_corim_endorsement(self, value: bool) -> Self
pub const fn with_corim_endorsement(self, value: bool) -> Self
Bits: 4..5
Sourcepub const fn set_corim_endorsement(&mut self, value: bool)
pub const fn set_corim_endorsement(&mut self, value: bool)
Bits: 4..5