pub struct IgvmSignal(/* private fields */);Expand description
Bitmap indicates a signal to requestor 0 - IGVM_SIGNAL_RETRY_RECOMMENDED_BIT: Retry recommendation 1 - IGVM_SIGNAL_SKIP_HW_UNSEALING_RECOMMENDED_BIT: Skip hardware unsealing 2 - IGVM_SIGNAL_RSA_AES_KEY_WRAP_384_USED_BIT: Set by the IGVM Agent to indicate that the agent asked AKV for the SHA-384 variant (RSA_AES_KEY_WRAP_384) and AKV used it to wrap the key in the payload. If this bit is clear, AKV wrapped the key with the default CKM_RSA_AES_KEY_WRAP scheme (inner RSA-OAEP using SHA-1). 3 - IGVM_SIGNAL_CORIM_ENDORSEMENT_REQUESTED_BIT: Set by the IGVM Agent to indicate that the agent requested the CoRIM endorsement.
Implementations
Sourceimpl IgvmSignal
impl IgvmSignal
Sourcepub const fn with_retry_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_retry_checked(self, value: bool) -> Result<Self, ()>
Bits: 0..1
Sourcepub const fn with_retry(self, value: bool) -> Self
pub const fn with_retry(self, value: bool) -> Self
Bits: 0..1
Sourcepub const fn skip_hw_unsealing(&self) -> bool
pub const fn skip_hw_unsealing(&self) -> bool
Bits: 1..2
Sourcepub const fn with_skip_hw_unsealing_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_skip_hw_unsealing_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 1..2
Sourcepub const fn with_skip_hw_unsealing(self, value: bool) -> Self
pub const fn with_skip_hw_unsealing(self, value: bool) -> Self
Bits: 1..2
Sourcepub const fn set_skip_hw_unsealing(&mut self, value: bool)
pub const fn set_skip_hw_unsealing(&mut self, value: bool)
Bits: 1..2
Sourcepub const fn set_skip_hw_unsealing_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_skip_hw_unsealing_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 1..2
Sourcepub const fn rsa_aes_key_wrap_384_used(&self) -> bool
pub const fn rsa_aes_key_wrap_384_used(&self) -> bool
Bits: 2..3
Sourcepub const fn with_rsa_aes_key_wrap_384_used_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_rsa_aes_key_wrap_384_used_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 2..3
Sourcepub const fn with_rsa_aes_key_wrap_384_used(self, value: bool) -> Self
pub const fn with_rsa_aes_key_wrap_384_used(self, value: bool) -> Self
Bits: 2..3
Sourcepub const fn set_rsa_aes_key_wrap_384_used(&mut self, value: bool)
pub const fn set_rsa_aes_key_wrap_384_used(&mut self, value: bool)
Bits: 2..3
Sourcepub const fn set_rsa_aes_key_wrap_384_used_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_rsa_aes_key_wrap_384_used_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 2..3
Sourcepub const fn corim_endorsement_requested(&self) -> bool
pub const fn corim_endorsement_requested(&self) -> bool
Bits: 3..4
Sourcepub const fn with_corim_endorsement_requested_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_corim_endorsement_requested_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 3..4
Sourcepub const fn with_corim_endorsement_requested(self, value: bool) -> Self
pub const fn with_corim_endorsement_requested(self, value: bool) -> Self
Bits: 3..4
Sourcepub const fn set_corim_endorsement_requested(&mut self, value: bool)
pub const fn set_corim_endorsement_requested(&mut self, value: bool)
Bits: 3..4