pub enum DtError {
NoDeviceTree,
DeviceTree(Error<'static>),
CommandLineSize,
Vtl2Vmbus,
Vtl0Vmbus,
NotEnoughVtl0Mmio,
NotEnoughVtl2Mmio,
}Expand description
Errors when reading the host device tree.
Variants
NoDeviceTree
Host did not provide a device tree.
DeviceTree(Error<'static>)
Invalid device tree.
CommandLineSize
PartitionInfo’s command line is too small to write the parsed legacy command line.
Vtl2Vmbus
Device tree did not contain a vmbus node for VTL2.
Vtl0Vmbus
Device tree did not contain a vmbus node for VTL0.
NotEnoughVtl0Mmio
Host provided high MMIO range is insufficient to cover VTL0 and VTL2.
NotEnoughVtl2Mmio
Host provided MMIO range is insufficient to cover VTL2.