allocate_private_pool

Function allocate_private_pool 

fn allocate_private_pool(
    address_space: &mut AddressSpaceManager,
    vtl2_ram: &[MemoryEntry],
    pool_size_bytes: u64,
    force_numa_split: bool,
    enable_vtl2_gpa_pool: Vtl2GpaPoolConfig,
    device_dma_page_count: Option<u64>,
    vp_count: usize,
    mem_size: u64,
)
Allocate the private pool across NUMA nodes.

By default, tries to allocate the entire pool on NUMA node 0 (preserving previous behavior). If that fails, or if force_numa_split is true, the pool is split evenly across all available NUMA nodes (one range per node).