OffStackRef

Struct OffStackRef 

pub struct OffStackRef<'a, T>(&'a mut T, BorrowRef<'a>);
A reference returned by off_stack.

Tuple Fields

0: &'a mut T1: BorrowRef<'a>

Implementations

Source

impl<'a, T> OffStackRef<'a, T>

pub fn leak(this: Self) -> &'a mut T

Leaks the borrow, returning the reference.

This will lead to a panic if there is an attempt to borrow the value again (e.g., if the function invoking the off_stack macro is called again).