pub fn create_disk_type(
path: &Path,
size: u64,
options: OpenDiskOptions,
) -> Result<Resource<DiskHandleKind>>Expand description
Create and open the resources needed for using a disk from a file at path.
pub fn create_disk_type(
path: &Path,
size: u64,
options: OpenDiskOptions,
) -> Result<Resource<DiskHandleKind>>Create and open the resources needed for using a disk from a file at path.