pub fn hypervisor_resource(name: &str) -> Result<Resource<HypervisorKind>>Expand description
Returns a Resource<HypervisorKind> for the named backend.
This validates that the name matches a registered probe and checks availability.
pub fn hypervisor_resource(name: &str) -> Result<Resource<HypervisorKind>>Returns a Resource<HypervisorKind> for the named backend.
This validates that the name matches a registered probe and checks availability.