CpuSet

Struct CpuSet 

pub struct CpuSet(/* private fields */);
A [libc::cpu_set_t] sized appropriately to the number of processors on this machine.

This is needed to support more than 1024 processors, since the statically sized cpu_set_t only has room for that many processors.

Implementations

Source

impl CpuSet

pub fn new() -> Self

Allocates a new empty CPU set.

pub fn buffer_len(&self) -> usize

Gets the length of the buffer in bytes, for use with syscalls.

pub fn as_ptr(&self) -> *const cpu_set_t

Gets a pointer for use with syscalls.

pub fn as_mut_ptr(&mut self) -> *mut cpu_set_t

Gets a mutable pointer for use with syscalls.

pub fn set(&mut self, index: u32) -> &mut Self

Sets processor index in the CPU set.

Panics if index is greater than or equal to max_procs.

pub fn set_mask_hex_string( &mut self, string_mask: &[u8], ) -> Result<(), InvalidHexString>

Sets all the CPUs in the linear bitmask mask, which is an ASCII hexadecimal string.

This is useful for parsing the output of /sys/devices/system/cpu/topology.

pub fn set_mask_list(&mut self, list: &str) -> Result<(), InvalidCpuList>

Sets all the CPUs in the list list, which is a comma-separated list of ranges and single CPUs.

This is useful for parsing the output of /sys/devices/system/cpu/online.

pub fn is_set(&self, index: u32) -> bool

Returns whether processor index is set.

Panics if index is greater than or equal to max_procs.