IoUringDriver

Trait IoUringDriver 

pub trait IoUringDriver {
    type Submitter: IoUringSubmit;

    // Required method
    fn io_uring_submitter(&self) -> Option<&Self::Submitter>;
}
Component trait for drivers that optionally support io-uring submission.

All types that participate in the Driver blanket impl on Linux must implement this trait. There is no default—implementors must explicitly return None if they do not support io-uring, so that wrapper types do not silently drop the capability.

Required Associated Types

type Submitter: IoUringSubmit

The type used to submit io-uring operations.

Use NoIoUring if the driver does not support io-uring.

Required Methods

fn io_uring_submitter(&self) -> Option<&Self::Submitter>

Returns an io-uring submitter.

Implementors

Source

impl IoUringDriver for LocalDriver

Available on Linux only.
Source

impl IoUringDriver for EpollDriver

Source

type Submitter = EpollIoUring