PolledChild

Struct PolledChild 

pub struct PolledChild<C> { /* private fields */ }
An owned child process with an asynchronous exit wait.

The wait field is declared before child so that the backend wait registration is dropped before the child’s underlying handle or fd.

Implementations

Source

impl<C> PolledChild<C>

pub fn into_inner(self) -> C

Returns the inner child, dropping the wait registration.

pub fn get(&self) -> &C

Gets a reference to the inner child.

pub fn get_mut(&mut self) -> &mut C

Gets a mutable reference to the inner child.

Source

impl PolledChild<Child>

pub fn new(driver: &(impl ?Sized + Driver), child: Child) -> Result<Self>

Creates a new PolledChild wrapping a std::process::Child.

pub fn poll_wait(&mut self, cx: &mut Context<'_>) -> Poll<Result<ExitStatus>>

Polls for the child process to exit.

pub fn wait(&mut self) -> impl '_ + Unpin + Future<Output = Result<ExitStatus>>

Waits for the child process to exit.

Source

impl PolledChild<Child>

pub fn new(driver: &(impl ?Sized + Driver), child: Child) -> Result<Self>

Creates a new PolledChild wrapping a [pal::unix::process::Child].

pub fn poll_wait(&mut self, cx: &mut Context<'_>) -> Poll<Result<ExitStatus>>

Polls for the child process to exit.

pub fn wait(&mut self) -> impl '_ + Unpin + Future<Output = Result<ExitStatus>>

Waits for the child process to exit.