pub struct PolledSocket<T> { /* private fields */ }Expand description
A polled socket.
Implementations
Sourceimpl<T: AsSockRef> PolledSocket<T>
impl<T: AsSockRef> PolledSocket<T>
Sourcepub fn new(driver: &(impl ?Sized + Driver), socket: T) -> Result<Self>
pub fn new(driver: &(impl ?Sized + Driver), socket: T) -> Result<Self>
Creates a new polled socket.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Extracts the inner socket.
Sourcepub fn poll_peek(
&mut self,
cx: &mut Context<'_>,
buf: &mut [u8],
) -> Poll<Result<usize>>
pub fn poll_peek( &mut self, cx: &mut Context<'_>, buf: &mut [u8], ) -> Poll<Result<usize>>
Polls for peeking at incoming data without consuming it.
On success, the peeked bytes are written to the start of buf and the
number of bytes peeked is returned. A return value of Ok(0) indicates
that the peer has closed the connection (or that buf was empty).
The peeked data remains in the socket’s receive buffer, so a subsequent read (or peek) will observe the same bytes.
Sourceimpl<T> PolledSocket<T>
impl<T> PolledSocket<T>
Sourceimpl<T> PolledSocket<T>
impl<T> PolledSocket<T>
Sourcepub fn poll_io<F, R>(
&mut self,
cx: &mut Context<'_>,
slot: InterestSlot,
events: PollEvents,
f: F,
) -> Poll<Result<R>>
pub fn poll_io<F, R>( &mut self, cx: &mut Context<'_>, slot: InterestSlot, events: PollEvents, f: F, ) -> Poll<Result<R>>
Calls nonblocking operation f when the socket has least one event in
events ready.
Uses interest slot slot to allow multiple concurrent operations.
If f returns Err(err) with err.kind() == io::ErrorKind::WouldBlock, then this re-polls the socket for readiness
and returns Poll::Pending.
Sourceimpl<T> PolledSocket<T>
impl<T> PolledSocket<T>
Sourcepub fn split(self) -> (ReadHalf<T>, WriteHalf<T>)
pub fn split(self) -> (ReadHalf<T>, WriteHalf<T>)
Splits the socket into a read and write half that can be used concurrently.
This is more flexible and efficient than
[futures::io::AsyncReadExt::split], since it avoids holding a lock
while calling into the kernel, and it provides access to the underlying
socket for more advanced operations.
Sourceimpl PolledSocket<Socket>
impl PolledSocket<Socket>
Sourceimpl PolledSocket<TcpStream>
impl PolledSocket<TcpStream>
Sourcepub async fn connect_tcp(
driver: &(impl ?Sized + Driver),
addr: SocketAddr,
) -> Result<Self>
pub async fn connect_tcp( driver: &(impl ?Sized + Driver), addr: SocketAddr, ) -> Result<Self>
Creates a new connected TCP stream socket.
Sourceimpl PolledSocket<Socket>
impl PolledSocket<Socket>