#[repr(transparent)]pub struct DeviceId(pub u16);Expand description
Device IDs allocated under VENDOR_ID for OpenVMM’s first-party
emulated devices.
These are centrally managed by Microsoft: a device ID must be formally assigned before use so that it does not collide with any other Microsoft product that shares this vendor ID.
Tuple Fields
0: u16Implementations
Sourceimpl DeviceId
impl DeviceId
Sourcepub const PCIE_ROOT_PORT: DeviceId
pub const PCIE_ROOT_PORT: DeviceId
PCIe root port.
Sourcepub const PCIE_UPSTREAM_SWITCH_PORT: DeviceId
pub const PCIE_UPSTREAM_SWITCH_PORT: DeviceId
PCIe upstream switch port.
Sourcepub const PCIE_DOWNSTREAM_SWITCH_PORT: DeviceId
pub const PCIE_DOWNSTREAM_SWITCH_PORT: DeviceId
PCIe downstream switch port.