LinkSpeed

Struct LinkSpeed 

#[repr(transparent)]
pub struct LinkSpeed(pub u32);
PCIe Link Speed encoding values for use in Link Capabilities and other registers.

Values are defined in PCIe Base Specification for the Max Link Speed field in Link Capabilities Register and similar fields.

Tuple Fields

0: u32

Implementations

Source

impl LinkSpeed

pub const Speed2_5GtS: LinkSpeed

2.5 GT/s link speed

pub const Speed5_0GtS: LinkSpeed

5.0 GT/s link speed

pub const Speed8_0GtS: LinkSpeed

8.0 GT/s link speed

pub const Speed16_0GtS: LinkSpeed

16.0 GT/s link speed

pub const Speed32_0GtS: LinkSpeed

32.0 GT/s link speed

pub const Speed64_0GtS: LinkSpeed

64.0 GT/s link speed

Source

impl LinkSpeed

pub const fn from_bits(bits: u32) -> Self

pub const fn into_bits(self) -> u32