LinkWidth

Struct LinkWidth 

#[repr(transparent)]
pub struct LinkWidth(pub u32);
PCIe Link Width encoding values for use in Link Capabilities and other registers.

Values are defined in PCIe Base Specification for the Max Link Width field in Link Capabilities Register and similar fields.

Tuple Fields

0: u32

Implementations

Source

impl LinkWidth

pub const X1: LinkWidth

x1 link width

pub const X2: LinkWidth

x2 link width

pub const X4: LinkWidth

x4 link width

pub const X8: LinkWidth

x8 link width

pub const X16: LinkWidth

x16 link width

Source

impl LinkWidth

pub const fn from_bits(bits: u32) -> Self

pub const fn into_bits(self) -> u32