#[repr(transparent)]pub struct SupportedLinkSpeedsVector(pub u32);Expand description
PCIe Supported Link Speeds Vector encoding values for use in Link Capabilities 2 register.
Values are defined in PCIe Base Specification for the Supported Link Speeds Vector field in Link Capabilities 2 Register. Each bit represents support for a specific generation.
Tuple Fields
0: u32Implementations
Sourceimpl SupportedLinkSpeedsVector
impl SupportedLinkSpeedsVector
Sourcepub const UpToGen1: SupportedLinkSpeedsVector
pub const UpToGen1: SupportedLinkSpeedsVector
Support up to Gen 1 (2.5 GT/s)
Sourcepub const UpToGen2: SupportedLinkSpeedsVector
pub const UpToGen2: SupportedLinkSpeedsVector
Support up to Gen 2 (5.0 GT/s)
Sourcepub const UpToGen3: SupportedLinkSpeedsVector
pub const UpToGen3: SupportedLinkSpeedsVector
Support up to Gen 3 (8.0 GT/s)
Sourcepub const UpToGen4: SupportedLinkSpeedsVector
pub const UpToGen4: SupportedLinkSpeedsVector
Support up to Gen 4 (16.0 GT/s)
Sourcepub const UpToGen5: SupportedLinkSpeedsVector
pub const UpToGen5: SupportedLinkSpeedsVector
Support up to Gen 5 (32.0 GT/s)
Sourcepub const UpToGen6: SupportedLinkSpeedsVector
pub const UpToGen6: SupportedLinkSpeedsVector
Support up to Gen 6 (64.0 GT/s)