BistHeader

Struct BistHeader 

pub struct BistHeader(/* private fields */);
The BIST / Header Type / Latency Timer / Cache Line Size DWORD at config space offset 0x0C.

Bits 31-24Bits 23-16Bits 15-8Bits 7-0
BISTHeader TypeLatency TimerCache Line Size

Implementations

Source

impl BistHeader

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u32) -> Self

Convert from bits.

pub const fn into_bits(self) -> u32

Convert into bits.

pub const fn cache_line_size(&self) -> u8

Bits: 0..8

pub const fn with_cache_line_size_checked(self, value: u8) -> Result<Self, ()>

Bits: 0..8

pub const fn with_cache_line_size(self, value: u8) -> Self

Bits: 0..8

pub const fn set_cache_line_size(&mut self, value: u8)

Bits: 0..8

pub const fn set_cache_line_size_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 0..8

pub const fn latency_timer(&self) -> u8

Bits: 8..16

pub const fn with_latency_timer_checked(self, value: u8) -> Result<Self, ()>

Bits: 8..16

pub const fn with_latency_timer(self, value: u8) -> Self

Bits: 8..16

pub const fn set_latency_timer(&mut self, value: u8)

Bits: 8..16

pub const fn set_latency_timer_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 8..16

pub const fn header_type(&self) -> u8

Header layout type (0 = standard, 1 = PCI-to-PCI bridge).

Bits: 16..23

pub const fn with_header_type_checked(self, value: u8) -> Result<Self, ()>

Header layout type (0 = standard, 1 = PCI-to-PCI bridge).

Bits: 16..23

pub const fn with_header_type(self, value: u8) -> Self

Header layout type (0 = standard, 1 = PCI-to-PCI bridge).

Bits: 16..23

pub const fn set_header_type(&mut self, value: u8)

Header layout type (0 = standard, 1 = PCI-to-PCI bridge).

Bits: 16..23

pub const fn set_header_type_checked(&mut self, value: u8) -> Result<(), ()>

Header layout type (0 = standard, 1 = PCI-to-PCI bridge).

Bits: 16..23

pub const fn multi_function(&self) -> bool

When set, the device is part of a multi-function package.

Bits: 23..24

pub const fn with_multi_function_checked(self, value: bool) -> Result<Self, ()>

When set, the device is part of a multi-function package.

Bits: 23..24

pub const fn with_multi_function(self, value: bool) -> Self

When set, the device is part of a multi-function package.

Bits: 23..24

pub const fn set_multi_function(&mut self, value: bool)

When set, the device is part of a multi-function package.

Bits: 23..24

pub const fn set_multi_function_checked( &mut self, value: bool, ) -> Result<(), ()>

When set, the device is part of a multi-function package.

Bits: 23..24

pub const fn bist(&self) -> u8

Bits: 24..32

pub const fn with_bist_checked(self, value: u8) -> Result<Self, ()>

Bits: 24..32

pub const fn with_bist(self, value: u8) -> Self

Bits: 24..32

pub const fn set_bist(&mut self, value: u8)

Bits: 24..32

pub const fn set_bist_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 24..32