GenericPcieSwitch

Struct GenericPcieSwitch 

pub struct GenericPcieSwitch { /* private fields */ }
A PCI Express switch emulator that implements a complete switch with upstream and downstream ports.

A PCIe switch consists of:

  • One upstream switch port that connects to the parent (root port or another switch)
  • Multiple downstream switch ports that connect to children (endpoints or other switches)

The switch implements routing functionality to forward configuration space accesses between the upstream and downstream ports based on bus number assignments.

Implementations

Source

impl GenericPcieSwitch

pub fn new(definition: GenericPcieSwitchDefinition) -> Self

Constructs a new GenericPcieSwitch emulator.

pub fn name(&self) -> &Arc<str>

Get the name of this switch.

pub fn upstream_port(&self) -> &UpstreamSwitchPort

Get a reference to the upstream switch port.

pub fn downstream_ports(&self) -> Vec<(u8, Arc<str>)>

Enumerate the downstream ports of the switch.

pub fn add_pcie_device( &mut self, port: u8, name: &str, dev: Box<dyn GenericPciBusDevice>, ) -> Result<()>

Attach the provided GenericPciBusDevice to the port identified.