pub struct UpstreamSwitchPort { /* private fields */ }Expand description
A PCI Express upstream switch port emulator.
An upstream switch port connects a switch to its parent (e.g., root port or another switch). It appears as a Type 1 PCI-to-PCI bridge with PCIe capability indicating it’s an upstream switch port.
Implementations
Sourceimpl UpstreamSwitchPort
impl UpstreamSwitchPort
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs a new UpstreamSwitchPort emulator.
Sourcepub fn cfg_space(&self) -> &ConfigSpaceType1Emulator
pub fn cfg_space(&self) -> &ConfigSpaceType1Emulator
Get a reference to the configuration space emulator.
Sourcepub fn cfg_space_mut(&mut self) -> &mut ConfigSpaceType1Emulator
pub fn cfg_space_mut(&mut self) -> &mut ConfigSpaceType1Emulator
Get a mutable reference to the configuration space emulator.