pub struct AgentImage { /* private fields */ }Expand description
The description and artifacts needed to build a pipette disk image for a VM.
Implementations
Sourceimpl AgentImage
impl AgentImage
Sourcepub fn new(os_flavor: OsFlavor) -> Self
pub fn new(os_flavor: OsFlavor) -> Self
Resolves the artifacts needed to build a disk image for a VM.
Sourcepub fn with_pipette(
self,
resolver: &ArtifactResolver<'_>,
arch: MachineArch,
) -> Self
pub fn with_pipette( self, resolver: &ArtifactResolver<'_>, arch: MachineArch, ) -> Self
Adds the appropriate pipette binary to the image
Sourcepub fn contains_pipette(&self) -> bool
pub fn contains_pipette(&self) -> bool
Check if the image contains pipette
Sourcepub fn has_extras(&self) -> bool
pub fn has_extras(&self) -> bool
Check if the image has extra files beyond pipette and cloud-init.
Sourcepub fn add_file(&mut self, name: &str, artifact: ResolvedArtifact)
pub fn add_file(&mut self, name: &str, artifact: ResolvedArtifact)
Adds an extra file to the disk image.