pub enum OpenvmmLogConfig {
TestDefault,
BuiltInDefault,
Custom(BTreeMap<String, String>),
}Expand description
Control the logging configuration of OpenVMM/OpenHCL.
Variants
TestDefault
Use the default log levels used by petri tests. This will forward
OPENVMM_LOG and OPENVMM_SHOW_SPANS from the environment if they are
set, otherwise it will use debug and true respectively
BuiltInDefault
Use the built-in default log levels of OpenHCL/OpenVMM (e.g. don’t pass OPENVMM_LOG or OPENVMM_SHOW_SPANS)
Custom(BTreeMap<String, String>)
Use the provided custom log levels, specified as key/value pairs. At this time,
simply uses the already-defined environment variables (e.g.
OPENVMM_LOG=info,disk_nvme=debug OPENVMM_SHOW_SPANS=true)
See the Guide and source code for configuring these logs.
- For the host VMM: see
enable_tracingintracing_init.rsfor details on the accepted keys and values. - For OpenHCL, see
init_tracing_backendinopenhcl/src/logging/mod.rsfor details on the accepted keys and values.