macro_rules! multitest {
($tests:expr) => { ... };
}Expand description
Defines a set of tests from an expression evaluating to a
Vec<TestCase>.
macro_rules! multitest {
($tests:expr) => { ... };
}Defines a set of tests from an expression evaluating to a
Vec<TestCase>.