macro_rules! test {
($f:ident, $req:expr) => { ... };
}Expand description
Defines a single test named after the async run function $f, using $req
to resolve its artifacts. See SimpleTest::new_async.
macro_rules! test {
($f:ident, $req:expr) => { ... };
}Defines a single test named after the async run function $f, using $req
to resolve its artifacts. See SimpleTest::new_async.