macro_rules! test_sync {
($f:ident, $req:expr) => { ... };
}Expand description
Defines a single test named after the synchronous run function $f, using
$req to resolve its artifacts. See SimpleTest::new_sync.
macro_rules! test_sync {
($f:ident, $req:expr) => { ... };
}Defines a single test named after the synchronous run function $f, using
$req to resolve its artifacts. See SimpleTest::new_sync.