macro_rules! unstable_test {
($f:ident, $req:expr, $reason:expr) => { ... };
}Expand description
Defines a single unstable test from a value that implements RunTest.
$reason documents why the test is unstable and is logged when an unstable
failure is ignored.