PetriVmConfigOpenVmm

Struct PetriVmConfigOpenVmm 

pub struct PetriVmConfigOpenVmm { /* private fields */ }
Configuration state for a test VM.

Implementations

Source

impl PetriVmConfigOpenVmm

pub async fn new( openvmm_path: &ResolvedArtifact, petri_vm_config: PetriVmConfig, resources: &PetriVmResources, properties: PetriVmProperties, ) -> Result<Self>

Create a new VM configuration.

Source

impl PetriVmConfigOpenVmm

pub fn with_vtl0_alias_map(self) -> Self

Enable the VTL0 alias map.

pub fn with_battery(self) -> Self

Enable the battery for the VM.

pub fn with_igvm_attest_test_config(self, config: IgvmAttestTestConfig) -> Self

Set test config for the GED’s IGVM attest request handler

pub fn with_nic(self) -> Self

Enable a synthnic for the VM.

Uses a mana emulator and the paravisor if a paravisor is present.

pub fn with_pcie_nic(self, port_name: &str, mac_address: MacAddress) -> Self

Add a PCIe NIC to the VM using the MANA emulator.

pub fn with_pcie_nvme(self, port_name: &str, subsystem_id: Guid) -> Self

Add a PCIe NVMe device to the VM using the NVMe emulator.

pub fn with_virtio_nic(self, port_name: &str) -> Self

Enable a virtio-net NIC for the VM backed by Consomme.

This exposes a virtio-net device on a PCIe root port, suitable for guests running virtio drivers (e.g. Linux with UEFI boot).

pub fn with_vtl2_relocation_mode(self, mode: Vtl2BaseAddressType) -> Self

Load with the specified VTL2 relocation mode.

pub fn with_memory_backing_file(self, path: impl Into<PathBuf>) -> Self

Use a file-backed memory region instead of anonymous RAM.

The file at the given path will be created (or opened) and sized to match the VM’s configured memory. Guest memory is then backed by this file, which persists across snapshot save/restore.

pub fn with_pcie_root_topology( self, segment_count: u64, root_complex_per_segment: u64, root_ports_per_root_complex: u64, ) -> Self

Add a symmetric PCIe topology to the VM based on some basic scale factors

All root ports are named according to their index within their parent using the naming scheme sXrcYrpZ. For example, the third root port on the fourth root complex in segment 0 would be named s0rc3rp2.

pub fn with_pcie_switch( self, port_name: &str, switch_name: &str, port_count: u8, hotplug: bool, ) -> Self

Add a PCIe switch to the VM.

pub fn with_custom_config(self, f: impl FnOnce(&mut Config)) -> Self

This is intended for special one-off use cases. As soon as something is needed in multiple tests we should consider making it a supported pattern.

pub fn with_allow_early_vtl0_access(self, allow: bool) -> Self

Specifies whether VTL2 should be allowed to access VTL0 memory before it sets any VTL protections.

This is needed just for the TMK VMM, and only until it gains support for setting VTL protections.

Source

impl PetriVmConfigOpenVmm

pub async fn run(self) -> Result<(PetriVmOpenVmm, PetriVmRuntimeConfig)>

Run the VM, configuring pipette to automatically start if it is included in the config