pub enum TestRequirement {
ExecutionEnvironment(ExecutionEnvironment),
Vendor(Vendor),
Isolation(IsolationType),
RequiresCapability(&'static str),
And(Box<TestRequirement>, Box<TestRequirement>),
Or(Box<TestRequirement>, Box<TestRequirement>),
Not(Box<TestRequirement>),
Any,
}Expand description
A single requirement for a test to run.
Variants
ExecutionEnvironment(ExecutionEnvironment)
Execution environment requirement.
Vendor(Vendor)
Vendor requirement.
Isolation(IsolationType)
Isolation requirement.
RequiresCapability(&'static str)
Requires a named capability advertised by the execution environment or detected by petri.
Capabilities are how a test says “I need a specific resource to be
provisioned for me” without naming who provides it or how. The
execution environment can advertise capabilities via the
comma-separated PETRI_CAPABILITIES environment variable, and petri can
add capabilities that it detects itself. A test requiring a capability
that is not available is skipped, so such tests automatically
self-exclude on any host that cannot satisfy them.
And(Box<TestRequirement>, Box<TestRequirement>)
Logical AND of two requirements.
Or(Box<TestRequirement>, Box<TestRequirement>)
Logical OR of two requirements.
Not(Box<TestRequirement>)
Logical NOT of a requirement.
Any
Requirement satisfied by any host context.
Implementations
Sourceimpl TestRequirement
impl TestRequirement
Sourcepub fn and(self, other: TestRequirement) -> TestRequirement
pub fn and(self, other: TestRequirement) -> TestRequirement
Combine this requirement with another requirement using logical AND.
Sourcepub fn or(self, other: TestRequirement) -> TestRequirement
pub fn or(self, other: TestRequirement) -> TestRequirement
Combine this requirement with another requirement using logical OR.
Sourcepub fn not(self) -> TestRequirement
pub fn not(self) -> TestRequirement
Negate this requirement.
Sourcepub fn is_satisfied(&self, context: &HostContext) -> bool
pub fn is_satisfied(&self, context: &HostContext) -> bool
Evaluate if this requirement is satisfied with the given host context