pub struct OpenHclServicingFlags {
pub enable_nvme_keepalive: bool,
pub enable_mana_keepalive: bool,
pub override_version_checks: bool,
pub stop_timeout_hint_secs: Option<u16>,
}Expand description
Flags controlling servicing behavior.
Fields
enable_nvme_keepalive: boolPreserve DMA memory for NVMe devices if supported.
Defaults to true.
enable_mana_keepalive: boolPreserve DMA memory for MANA devices if supported.
override_version_checks: boolSkip any logic that the vmm may have to ignore servicing updates if the supplied igvm file version is not different than the one currently running.
stop_timeout_hint_secs: Option<u16>Hint to the OpenHCL runtime how much time to wait when stopping / saving the OpenHCL.