cargo_build_profile

Function cargo_build_profile 

pub fn cargo_build_profile() -> &'static str
Returns the Cargo build profile directory name for cross-compiled artifacts (e.g., pipette).

Infers the profile from the currently running binary’s path (looking for a release component in the executable path). Defaults to "debug".