resolve_bundle_name

Function resolve_bundle_name 

pub fn resolve_bundle_name(id: ErasedArtifactHandle) -> Option<&'static str>
Returns the bundle-relative file name for the given artifact.

This is the file_name argument that get_path would use when resolving this artifact. When creating a self-contained bundle for deployment, place the artifact at this relative path within the bundle directory, then set VMM_TESTS_CONTENT_DIR to the bundle directory at runtime.

Returns None for artifacts that don’t have a fixed bundle name (e.g., log directories).