RemoteAccess

Enum RemoteAccess 

pub enum RemoteAccess {
    Allow,
    LocalOnly,
}
Whether remote artifact access is allowed for a particular requirement.

Variants



Allow

Allow the artifact to resolve to a remote URL if not available locally.



LocalOnly

Require a local file; fail if not available locally.