pub struct TestArtifacts { /* private fields */ }Expand description
A resolved set of test artifacts, returned by
TestArtifactRequirements::resolve.
Implementations
Sourceimpl TestArtifacts
impl TestArtifacts
Sourcepub fn try_get(&self, artifact: impl AsArtifactHandle) -> Option<&Path>
pub fn try_get(&self, artifact: impl AsArtifactHandle) -> Option<&Path>
Try to get the resolved path of an artifact.
Returns None if the artifact was not required. Panics if the artifact
is only available remotely.
Sourcepub fn get(&self, artifact: impl AsArtifactHandle) -> &Path
pub fn get(&self, artifact: impl AsArtifactHandle) -> &Path
Get the resolved path of an artifact.
Panics if the artifact was not required or is only available remotely.
Sourcepub fn try_get_source(
&self,
artifact: impl AsArtifactHandle,
) -> Option<&ArtifactSource>
pub fn try_get_source( &self, artifact: impl AsArtifactHandle, ) -> Option<&ArtifactSource>
Try to get the resolved source of an artifact.
Sourcepub fn get_source(&self, artifact: impl AsArtifactHandle) -> &ArtifactSource
pub fn get_source(&self, artifact: impl AsArtifactHandle) -> &ArtifactSource
Get the resolved source of an artifact.