Shell

Struct Shell 

pub struct Shell<'a, T: Utf8Encoding> { /* private fields */ }
A stateful shell abstraction for interacting with the guest.

This is modeled after xshell::Shell.

Implementations

Source

impl<T> Shell<'_, T>
where T: Utf8Encoding,

pub fn change_dir(&mut self, path: impl AsRef<Utf8Path<T>>)

Change the effective working directory of the shell.

Other paths will be resolved relative to this directory.

pub fn chroot(&mut self, root: impl Into<String>)

Set the chroot directory for commands run by this shell.

Each spawned process will chroot into this directory before exec (Linux only). The shell itself is unaffected.

pub async fn read_file(&self, path: impl AsRef<Utf8Path<T>>) -> Result<String>

Reads a file from the guest into a string.

pub async fn read_file_raw( &self, path: impl AsRef<Utf8Path<T>>, ) -> Result<Vec<u8>>

Reads a file from the guest into a raw byte vector.

pub fn cmd(&self, program: impl AsRef<Utf8Path<T>>) -> Cmd<'_, T>

Creates a builder to execute a command inside the guest.

Consider using the cmd! macro.