pub fn try_find_resource_from_dll(
file: &File,
descriptor: &DllResourceDescriptor,
) -> Result<Option<(u64, usize)>>Expand description
Tries to read the given resource from a resource dll. If the given data buffer is not a valid PE file this function returns Ok(None). If it is a PE file, but the given resource can not be found or loaded this function returns Err(…). On success the return value contains the starting offset into the file and its length. TODO: change the return types to a proper enum with variants like ‘NotPeFile, NotFound, Ok(u64, usize)’