BounceBuffer

Struct BounceBuffer 

pub struct BounceBuffer { /* private fields */ }
A page-aligned temporary buffer used to double-buffer IO data.

When guest-provided buffers are not aligned to the disk’s sector size (or when the PagedRange constraints prevent direct IO), data is copied through a BounceBuffer:

  • Reads: IO is performed into the bounce buffer, then copied to guest memory via RequestBuffers::writer().
  • Writes: Data is copied from guest memory via RequestBuffers::reader() into the bounce buffer, then IO is performed from the bounce buffer.

The buffer is always page-aligned (4096 bytes), satisfying the alignment requirements of O_DIRECT and io_uring.

Implementations

Source

impl BounceBuffer

pub fn new(size: usize) -> Self

Allocates a new bounce buffer of size bytes.

pub fn as_mut_bytes(&mut self) -> &mut [u8]

Returns the bounce buffer memory.

pub fn io_vecs(&self) -> &[IoBuffer<'_>]

Returns a reference to the underlying buffer.

This is returned in a form convenient for using with IO functions.