Serial16550DeviceHandle

Struct Serial16550DeviceHandle 

pub struct Serial16550DeviceHandle {
    pub base: MmioOrIoPort,
    pub register_width: u8,
    pub irq: u32,
    pub io: Resource<SerialBackendHandle>,
    pub wait_for_rts: bool,
    pub debugger_mode: bool,
}
A handle to a 16550A serial device.

Fields

base: MmioOrIoPort

The base address for the device registers.

register_width: u8

The width of the device registers, in bytes.

irq: u32

The IRQ line for interrupts.

io: Resource<SerialBackendHandle>

The IO backend.

wait_for_rts: bool

If true, wait for the guest to set DTR+RTS modem bits before transmitting data to it. Otherwise, relay data from io even if the guest does not appear to be ready.

debugger_mode: bool

If true, insert a debugger-mode relay between the emulator and the backend that keeps the backend drained, dropping bytes instead of applying backpressure. Intended for WinDbg / KD-over-serial.

Implementations

Source

impl Serial16550DeviceHandle

pub fn com_port(com_port: ComPort, io: Resource<SerialBackendHandle>) -> Self

Helper function to construct a standard PC COM port.

pub fn com_ports(io: [Resource<SerialBackendHandle>; 4]) -> [Self; 4]

Helper function to construct the four standard PC COM ports.