#[repr(C)]pub struct Sdte {
pub part1: SdtePart1,
pub _reserved0: u64,
pub _reserved1: u64,
pub part2: SdtePart2,
pub _reserved2: u64,
pub part3: SdtePart3,
pub _reserved3: u64,
pub _reserved4: u64,
}Expand description
See Layout of the SDTE Structure in Table 68, “SEV-TIO Firmware Interface Specification”, Revision 0.91.
Fields
part1: SdtePart1Part 1 of the guest writable portion of the SDTE structure. These are split out to preserve specific alignment requirements from the spec.
_reserved0: u64Reserved. Set to 0.
_reserved1: u64Reserved. Set to 0.
part2: SdtePart2Part 2 of the guest writable portion of the SDTE structure. These are split out to preserve specific alignment requirements from the spec.
_reserved2: u64Reserved. Set to 0.
part3: SdtePart3Part 3 of the guest writable portion of the SDTE structure. These are split out to preserve specific alignment requirements from the spec.
_reserved3: u64Reserved. Set to 0.
_reserved4: u64Reserved. Set to 0.