pub struct TioMsgMmioConfigRspFlags(/* private fields */);Expand description
See TIO_MSG_MMIO_CONFIG_RSP flags in Table 66, “SEV-TIO Firmware Interface Specification”, Revision 0.91.
Implementations
Sourceimpl TioMsgMmioConfigRspFlags
impl TioMsgMmioConfigRspFlags
Sourcepub const fn msix_table(&self) -> bool
pub const fn msix_table(&self) -> bool
Indicates if the range maps MSI-X table.
Bits: 0..1
Sourcepub const fn with_msix_table_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_msix_table_checked(self, value: bool) -> Result<Self, ()>
Indicates if the range maps MSI-X table.
Bits: 0..1
Sourcepub const fn with_msix_table(self, value: bool) -> Self
pub const fn with_msix_table(self, value: bool) -> Self
Indicates if the range maps MSI-X table.
Bits: 0..1
Sourcepub const fn set_msix_table(&mut self, value: bool)
pub const fn set_msix_table(&mut self, value: bool)
Indicates if the range maps MSI-X table.
Bits: 0..1
Sourcepub const fn set_msix_table_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_msix_table_checked(&mut self, value: bool) -> Result<(), ()>
Indicates if the range maps MSI-X table.
Bits: 0..1
Sourcepub const fn with_msix_pba_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_msix_pba_checked(self, value: bool) -> Result<Self, ()>
Indicates if this range maps MSI-X PBA.
Bits: 1..2
Sourcepub const fn with_msix_pba(self, value: bool) -> Self
pub const fn with_msix_pba(self, value: bool) -> Self
Indicates if this range maps MSI-X PBA.
Bits: 1..2
Sourcepub const fn set_msix_pba(&mut self, value: bool)
pub const fn set_msix_pba(&mut self, value: bool)
Indicates if this range maps MSI-X PBA.
Bits: 1..2
Sourcepub const fn set_msix_pba_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_msix_pba_checked(&mut self, value: bool) -> Result<(), ()>
Indicates if this range maps MSI-X PBA.
Bits: 1..2
Sourcepub const fn non_tee_mem(&self) -> bool
pub const fn non_tee_mem(&self) -> bool
Indicates if the range can be mapped into either guest private memory or shared memory.
Bits: 2..3
Sourcepub const fn with_non_tee_mem_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_non_tee_mem_checked(self, value: bool) -> Result<Self, ()>
Indicates if the range can be mapped into either guest private memory or shared memory.
Bits: 2..3
Sourcepub const fn with_non_tee_mem(self, value: bool) -> Self
pub const fn with_non_tee_mem(self, value: bool) -> Self
Indicates if the range can be mapped into either guest private memory or shared memory.
Bits: 2..3
Sourcepub const fn set_non_tee_mem(&mut self, value: bool)
pub const fn set_non_tee_mem(&mut self, value: bool)
Indicates if the range can be mapped into either guest private memory or shared memory.
Bits: 2..3
Sourcepub const fn set_non_tee_mem_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_non_tee_mem_checked(&mut self, value: bool) -> Result<(), ()>
Indicates if the range can be mapped into either guest private memory or shared memory.
Bits: 2..3
Sourcepub const fn mem_attr_updateable(&self) -> bool
pub const fn mem_attr_updateable(&self) -> bool
Indicates if certain TDISP flags can be updated.
Bits: 3..4
Sourcepub const fn with_mem_attr_updateable_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_mem_attr_updateable_checked( self, value: bool, ) -> Result<Self, ()>
Indicates if certain TDISP flags can be updated.
Bits: 3..4
Sourcepub const fn with_mem_attr_updateable(self, value: bool) -> Self
pub const fn with_mem_attr_updateable(self, value: bool) -> Self
Indicates if certain TDISP flags can be updated.
Bits: 3..4
Sourcepub const fn set_mem_attr_updateable(&mut self, value: bool)
pub const fn set_mem_attr_updateable(&mut self, value: bool)
Indicates if certain TDISP flags can be updated.
Bits: 3..4