PerCpuState

Struct PerCpuState 

#[repr(C)]
pub struct PerCpuState { pub per_cpu_state_specified: bool, pub sidecar_starts_cpu: [bool; 400], }
Starting state for each CPU, supplied by openhcl_boot. For various reasons, openhcl_boot may have decided to instruct the linux kernel to start additional CPUs (notably, in the event that we know we’re about to spawn tasks on those CPUs right away to handle device interrupts).

Fields

per_cpu_state_specified: bool

Whether the per-CPU state is specified, since NUM_CPUS_SUPPORTED_FOR_PER_CPU_STATE is less than the maximum number of CPUs supported by OpenHCL and also by sidecar.

sidecar_starts_cpu: [bool; 400]

Whether the CPU should be started by the sidecar kernel. If false, the CPU will be started by (or remain with) the main kernel instead.