alloc_shared_memory

Function alloc_shared_memory 

pub fn alloc_shared_memory(size: usize, name: &str) -> Result<OwnedFd>
Allocates a mappable shared memory object of size bytes.

name labels the memfd so it appears as /memfd:<name> in /proc/{pid}/smaps on Linux.