pub fn deserialize_tdi_report(data: &[u8]) -> Result<TdiReportStruct>Expand description
Reads a TDI interface report provided from the host into a struct.
pub fn deserialize_tdi_report(data: &[u8]) -> Result<TdiReportStruct>Reads a TDI interface report provided from the host into a struct.