pub struct TdispTdiReportInterfaceInfo(/* private fields */);Expand description
PCI Express Base Specification Revision 6.3 Section 11.3.11 DEVICE_INTERFACE_REPORT
Implementations
Sourceimpl TdispTdiReportInterfaceInfo
impl TdispTdiReportInterfaceInfo
Sourcepub const fn firmware_update_allowed(&self) -> bool
pub const fn firmware_update_allowed(&self) -> bool
When 1, indicates that device firmware updates are not permitted while in CONFIG_LOCKED or RUN. When 0, indicates that firmware updates are permitted while in these states
Bits: 0..1
Sourcepub const fn with_firmware_update_allowed_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_firmware_update_allowed_checked( self, value: bool, ) -> Result<Self, ()>
When 1, indicates that device firmware updates are not permitted while in CONFIG_LOCKED or RUN. When 0, indicates that firmware updates are permitted while in these states
Bits: 0..1
Sourcepub const fn with_firmware_update_allowed(self, value: bool) -> Self
pub const fn with_firmware_update_allowed(self, value: bool) -> Self
When 1, indicates that device firmware updates are not permitted while in CONFIG_LOCKED or RUN. When 0, indicates that firmware updates are permitted while in these states
Bits: 0..1
Sourcepub const fn set_firmware_update_allowed(&mut self, value: bool)
pub const fn set_firmware_update_allowed(&mut self, value: bool)
When 1, indicates that device firmware updates are not permitted while in CONFIG_LOCKED or RUN. When 0, indicates that firmware updates are permitted while in these states
Bits: 0..1
Sourcepub const fn set_firmware_update_allowed_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_firmware_update_allowed_checked( &mut self, value: bool, ) -> Result<(), ()>
When 1, indicates that device firmware updates are not permitted while in CONFIG_LOCKED or RUN. When 0, indicates that firmware updates are permitted while in these states
Bits: 0..1
Sourcepub const fn generate_dma_without_pasid(&self) -> bool
pub const fn generate_dma_without_pasid(&self) -> bool
TDI generates DMA requests without PASID
Bits: 1..2
Sourcepub const fn with_generate_dma_without_pasid_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_generate_dma_without_pasid_checked( self, value: bool, ) -> Result<Self, ()>
TDI generates DMA requests without PASID
Bits: 1..2
Sourcepub const fn with_generate_dma_without_pasid(self, value: bool) -> Self
pub const fn with_generate_dma_without_pasid(self, value: bool) -> Self
TDI generates DMA requests without PASID
Bits: 1..2
Sourcepub const fn set_generate_dma_without_pasid(&mut self, value: bool)
pub const fn set_generate_dma_without_pasid(&mut self, value: bool)
TDI generates DMA requests without PASID
Bits: 1..2
Sourcepub const fn set_generate_dma_without_pasid_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_generate_dma_without_pasid_checked( &mut self, value: bool, ) -> Result<(), ()>
TDI generates DMA requests without PASID
Bits: 1..2
Sourcepub const fn generate_dma_with_pasid(&self) -> bool
pub const fn generate_dma_with_pasid(&self) -> bool
TDI generates DMA requests with PASID
Bits: 2..3
Sourcepub const fn with_generate_dma_with_pasid_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_generate_dma_with_pasid_checked( self, value: bool, ) -> Result<Self, ()>
TDI generates DMA requests with PASID
Bits: 2..3
Sourcepub const fn with_generate_dma_with_pasid(self, value: bool) -> Self
pub const fn with_generate_dma_with_pasid(self, value: bool) -> Self
TDI generates DMA requests with PASID
Bits: 2..3
Sourcepub const fn set_generate_dma_with_pasid(&mut self, value: bool)
pub const fn set_generate_dma_with_pasid(&mut self, value: bool)
TDI generates DMA requests with PASID
Bits: 2..3
Sourcepub const fn set_generate_dma_with_pasid_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_generate_dma_with_pasid_checked( &mut self, value: bool, ) -> Result<(), ()>
TDI generates DMA requests with PASID
Bits: 2..3
Sourcepub const fn ats_support_enabled(&self) -> bool
pub const fn ats_support_enabled(&self) -> bool
ATS supported and enabled for the TDI
Bits: 3..4
Sourcepub const fn with_ats_support_enabled_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ats_support_enabled_checked( self, value: bool, ) -> Result<Self, ()>
ATS supported and enabled for the TDI
Bits: 3..4
Sourcepub const fn with_ats_support_enabled(self, value: bool) -> Self
pub const fn with_ats_support_enabled(self, value: bool) -> Self
ATS supported and enabled for the TDI
Bits: 3..4
Sourcepub const fn set_ats_support_enabled(&mut self, value: bool)
pub const fn set_ats_support_enabled(&mut self, value: bool)
ATS supported and enabled for the TDI
Bits: 3..4
Sourcepub const fn set_ats_support_enabled_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ats_support_enabled_checked( &mut self, value: bool, ) -> Result<(), ()>
ATS supported and enabled for the TDI
Bits: 3..4
Sourcepub const fn prs_support_enabled(&self) -> bool
pub const fn prs_support_enabled(&self) -> bool
PRS supported and enabled for the TDI
Bits: 4..5
Sourcepub const fn with_prs_support_enabled_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_prs_support_enabled_checked( self, value: bool, ) -> Result<Self, ()>
PRS supported and enabled for the TDI
Bits: 4..5
Sourcepub const fn with_prs_support_enabled(self, value: bool) -> Self
pub const fn with_prs_support_enabled(self, value: bool) -> Self
PRS supported and enabled for the TDI
Bits: 4..5
Sourcepub const fn set_prs_support_enabled(&mut self, value: bool)
pub const fn set_prs_support_enabled(&mut self, value: bool)
PRS supported and enabled for the TDI
Bits: 4..5