Enum Command
pub enum Command {
GetDeviceInterfaceInfo(TdispCommandRequestGetDeviceInterfaceInfo),
Bind(TdispCommandRequestBind),
GetTdiReport(TdispCommandRequestGetTdiReport),
StartTdi(TdispCommandRequestStartTdi),
Unbind(TdispCommandRequestUnbind),
}Expand description
The command and its payload. Exactly one variant must be set.
Variants
GetDeviceInterfaceInfo(TdispCommandRequestGetDeviceInterfaceInfo)
Bind(TdispCommandRequestBind)
GetTdiReport(TdispCommandRequestGetTdiReport)
StartTdi(TdispCommandRequestStartTdi)
Unbind(TdispCommandRequestUnbind)
Implementations
impl Command
impl Command
pub fn merge<B>(
field: &mut Option<Command>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Command>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.