TdispGuestOperationErrorCode

Enum TdispGuestOperationErrorCode 

#[repr(i32)]
pub enum TdispGuestOperationErrorCode { Unknown = 0, Success = 1, InvalidGuestProtocolRequest = 2, InvalidDeviceState = 3, InvalidGuestUnbindReason = 4, InvalidGuestCommandId = 5, NotImplemented = 6, HostFailedToProcessCommand = 7, InvalidGuestAttestationReportState = 8, InvalidGuestAttestationReportType = 9, }
Error code returned by TDISP operations dispatched by the guest. Corresponds to TdispGuestOperationErrorCode in lib.rs.

Variants



Unknown = 0

Unknown error code.



Success = 1

The operation was successful.



InvalidGuestProtocolRequest = 2

The requested guest protocol type was not valid for this host.



InvalidDeviceState = 3

The current TDI state is incorrect for this operation.



InvalidGuestUnbindReason = 4

The reason for this unbind is invalid.



InvalidGuestCommandId = 5

Invalid TDI command ID.



NotImplemented = 6

Operation requested was not implemented.



HostFailedToProcessCommand = 7

Host failed to process command.



InvalidGuestAttestationReportState = 8

The device was not in the Locked or Run state when the attestation report was requested.



InvalidGuestAttestationReportType = 9

Invalid attestation report type requested.

Implementations



impl TdispGuestOperationErrorCode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of TdispGuestOperationErrorCode.

pub fn from_i32(value: i32) -> Option<TdispGuestOperationErrorCode>

Converts an i32 to a TdispGuestOperationErrorCode, or None if value is not a valid variant.



impl TdispGuestOperationErrorCode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<TdispGuestOperationErrorCode>

Creates an enum from field names used in the ProtoBuf definition.