Enum TdispGuestUnbindReason
#[repr(i32)]pub enum TdispGuestUnbindReason {
Unknown = 0,
Graceful = 1,
}Expand description
For a guest-initiated unbind, the guest can provide a reason.
Variants
Unknown = 0
The guest requested to unbind the device for an unspecified reason.
Graceful = 1
The guest requested to unbind the device because the device is being detached.
Implementations
impl TdispGuestUnbindReason
impl TdispGuestUnbindReason
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<TdispGuestUnbindReason>
pub fn from_str_name(value: &str) -> Option<TdispGuestUnbindReason>
Creates an enum from field names used in the ProtoBuf definition.