Enum TdispReportType
#[repr(i32)]pub enum TdispReportType {
Invalid = 0,
GuestDeviceId = 1,
InterfaceReport = 2,
CertificateChain = 3,
Measurements = 4,
IsRegistered = 5,
}Expand description
Represents a type of report that can be requested from the TDI (VF).
Variants
Invalid = 0
Invalid report type. All usages of this report type should be treated as an error.
GuestDeviceId = 1
Guest requests the guest device ID of the TDI.
InterfaceReport = 2
Guest requests the interface report of the TDI.
CertificateChain = 3
Guest requests the certificate chain of the physical device.
Measurements = 4
Guest requests the measurements of the physical device.
IsRegistered = 5
Guest requests whether the physical device is registered.
Implementations
impl TdispReportType
impl TdispReportType
impl TdispReportType
impl TdispReportType
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<TdispReportType>
pub fn from_str_name(value: &str) -> Option<TdispReportType>
Creates an enum from field names used in the ProtoBuf definition.