Struct TdispDeviceInterfaceInfo
pub struct TdispDeviceInterfaceInfo {
pub guest_protocol_type: i32,
pub supported_features: u64,
pub tdisp_device_id: u64,
}Expand description
Represents the TDISP device interface information, such as the version and supported features.
Fields
guest_protocol_type: i32The version of the TDISP interface the host has chosen for this guest to use.
supported_features: u64Bitfield advertising feature set capabilities.
tdisp_device_id: u64Device ID used to communicate with firmware for this particular device.
Implementations
impl TdispDeviceInterfaceInfo
impl TdispDeviceInterfaceInfo
pub fn guest_protocol_type(&self) -> TdispGuestProtocolType
pub fn guest_protocol_type(&self) -> TdispGuestProtocolType
Returns the enum value of guest_protocol_type, or the default if the field is set to an invalid enum value.
pub fn set_guest_protocol_type(&mut self, value: TdispGuestProtocolType)
pub fn set_guest_protocol_type(&mut self, value: TdispGuestProtocolType)
Sets guest_protocol_type to the provided enum value.