pub fn new_null_tdisp_interface(
debug_device_id: &str,
) -> TdispHostDeviceTargetEmulatorExpand description
Implements the host side of the TDISP interface for a mock device that does nothing.
pub fn new_null_tdisp_interface(
debug_device_id: &str,
) -> TdispHostDeviceTargetEmulatorImplements the host side of the TDISP interface for a mock device that does nothing.