pub struct FieldFormatter;Expand description
Field formatter that fixes a few issues with the default formatter:
- Displays the full error source chain, not just the first error.
- Displays unsigned values as hex instead of decimal, improving readability for values that we tend to log in OpenVMM.