#[repr(C)]pub struct EfiRtPropertiesTable {
pub version: u16,
pub length: u16,
pub runtime_services_supported: u32,
}Expand description
From UEFI spec 4.6 — EFI_RT_PROPERTIES_TABLE
Installed in the EFI Configuration Table to tell the OS which runtime
services are supported. Setting runtime_services_supported to zero
means no runtime services are backed by real code.
Fields
version: u16length: u16runtime_services_supported: u32Implementations
Sourceimpl EfiRtPropertiesTable
impl EfiRtPropertiesTable
Sourcepub const NONE_SUPPORTED: Self
pub const NONE_SUPPORTED: Self
A table advertising that no runtime services are supported.