#[repr(C)]pub struct EfiSystemTable {Show 18 fields
pub signature: u64,
pub revision: u32,
pub header_size: u32,
pub crc32: u32,
pub reserved: u32,
pub firmware_vendor: u64,
pub firmware_revision: u32,
pub _pad0: u32,
pub console_in_handle: u64,
pub con_in: u64,
pub console_out_handle: u64,
pub con_out: u64,
pub standard_error_handle: u64,
pub std_err: u64,
pub runtime_services: u64,
pub boot_services: u64,
pub number_of_table_entries: u64,
pub configuration_table: u64,
}Expand description
From UEFI spec 4.6 — EFI_SYSTEM_TABLE
Minimal layout covering header fields and the pointers needed by the Linux EFI stub (firmware vendor, configuration table).
Fields
signature: u64revision: u32header_size: u32crc32: u32reserved: u32firmware_vendor: u64firmware_revision: u32_pad0: u32console_in_handle: u64con_in: u64console_out_handle: u64con_out: u64standard_error_handle: u64std_err: u64runtime_services: u64boot_services: u64number_of_table_entries: u64configuration_table: u64Trait Implementations
Sourceimpl Clone for EfiSystemTable
impl Clone for EfiSystemTable
Sourcefn clone(&self) -> EfiSystemTable
fn clone(&self) -> EfiSystemTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EfiSystemTable
impl Debug for EfiSystemTable
Sourceimpl Default for EfiSystemTable
impl Default for EfiSystemTable
Sourcefn default() -> EfiSystemTable
fn default() -> EfiSystemTable
Returns the “default value” for a type. Read more
Sourceimpl IntoBytes for EfiSystemTable
impl IntoBytes for EfiSystemTable
Sourceimpl KnownLayout for EfiSystemTablewhere
u64: KnownLayout,
impl KnownLayout for EfiSystemTablewhere
u64: KnownLayout,
Sourcetype PointerMetadata = <u64 as KnownLayout>::PointerMetadata
type PointerMetadata = <u64 as KnownLayout>::PointerMetadata
The type of metadata stored in a pointer to
Self. Read morefn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
fn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
Computes the size of an object of type
Self with the given pointer
metadata. Read moreimpl Copy for EfiSystemTable
impl Immutable for EfiSystemTable