#[repr(C)]pub struct VpGpaPageChunk {
pub header: VbsChunkHeader,
pub metadata: u64,
pub page_number: u64,
}Expand description
Structure describing the page to be measured.
Page data is hashed after struct to generate digest, if not a full page, measurable data will be padded to VBS_VP_CHUNK_SIZE_BYTES
Fields
header: VbsChunkHeadermetadata: u64page_number: u64Trait Implementations
Sourceimpl IntoBytes for VpGpaPageChunk
impl IntoBytes for VpGpaPageChunk
Sourceimpl KnownLayout for VpGpaPageChunkwhere
u64: KnownLayout,
impl KnownLayout for VpGpaPageChunkwhere
u64: KnownLayout,
Sourcetype PointerMetadata = <u64 as KnownLayout>::PointerMetadata
type PointerMetadata = <u64 as KnownLayout>::PointerMetadata
The type of metadata stored in a pointer to
Self. Read morefn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
fn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
Computes the size of an object of type
Self with the given pointer
metadata. Read moreimpl Immutable for VpGpaPageChunkwhere
VbsChunkHeader: Immutable,
u64: Immutable,