pub struct Group { /* private fields */ }Implementations
Sourceimpl Group
impl Group
Sourcepub fn from_file(file: File) -> Self
pub fn from_file(file: File) -> Self
Construct a Group from a pre-opened VFIO group file descriptor.
pub fn open(group: u64) -> Result<Self>
pub fn open_noiommu(group: u64) -> Result<Self>
pub fn find_group_for_device(device_sysfs_path: &Path) -> Result<u64>
pub fn open_device(&self, device_id: &str) -> Result<Device>
pub fn set_container(&self, container: &Container) -> Result<()>
Sourcepub fn try_set_container(&self, container: &Container) -> Result<bool>
pub fn try_set_container(&self, container: &Container) -> Result<bool>
Try to attach this group to the given container.
Returns Ok(true) if the group was successfully attached, Ok(false)
if the kernel rejected the pairing (EINVAL — the IOMMU domains are
incompatible), or Err on unexpected failures.
pub fn status(&self) -> Result<GroupStatus>
Sourcepub fn set_keep_alive(&self, device_id: &str) -> Result<()>
pub fn set_keep_alive(&self, device_id: &str) -> Result<()>
Skip VFIO device reset when kernel is reloaded during servicing. This feature is non-upstream version of our kernel and will be eventually replaced with iommufd.