SnpPartitionConfig

Enum SnpPartitionConfig 

pub enum SnpPartitionConfig {
    DirectBoot {
        restricted_injection: bool,
    },
    Igvm(Box<SnpConfig>),
}
SNP boot configuration needed before a backend creates a partition.

Variants



DirectBoot

A loader-generated Linux direct-boot VMSA.

Fields

restricted_injection: bool

Enables restricted interrupt injection in the partition and VMSA.



Igvm(Box<SnpConfig>)

Launch configuration extracted from an IGVM file.