MsiRequest

Struct MsiRequest 

pub struct MsiRequest {
    pub address: u64,
    pub data: u32,
}
A message-signaled interrupt request.

Fields

address: u64

The MSI address.

data: u32

The data payload.

Implementations

Source

impl MsiRequest

pub fn new_x86( mode: DeliveryMode, destination: u32, is_logical_destination: bool, vector: u8, is_level_triggered: bool, ) -> Self

Creates a new MSI request for an x86 system.

pub fn as_x86(&self) -> (MsiAddress, MsiData)

Interprets the MSI address and data as an x86 MSI request.

pub fn hv_x86_interrupt_control(&self) -> HvInterruptControl

Constructs an interrupt control for sending this interrupt request to a Microsoft hypervisor.

Note that this may produce an invalid interrupt control that the hypervisor will reject.