pub struct NestedState {
pub data: Vec<u8>,
}Expand description
Opaque nested-virtualization state blob for save/restore.
Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for NestedState
impl Clone for NestedState
Sourcefn clone(&self) -> NestedState
fn clone(&self) -> NestedState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NestedState
impl Debug for NestedState
Sourceimpl Default for NestedState
impl Default for NestedState
Sourcefn default() -> NestedState
fn default() -> NestedState
Returns the “default value” for a type. Read more
Sourceimpl DefaultEncoding for NestedState
impl DefaultEncoding for NestedState
Sourceimpl DescribeTable for NestedState
impl DescribeTable for NestedState
Sourceconst DESCRIPTION: MessageDescription<'static>
const DESCRIPTION: MessageDescription<'static>
The protobuf message description for this type.
Sourceimpl PartialEq for NestedState
impl PartialEq for NestedState
Sourceimpl StateElement<X86PartitionCapabilities, X86VpInfo> for NestedState
impl StateElement<X86PartitionCapabilities, X86VpInfo> for NestedState
Sourcefn is_present(caps: &X86PartitionCapabilities) -> bool
fn is_present(caps: &X86PartitionCapabilities) -> bool
Returns whether this state is present for the partition, based on the
partition capabilities.
Sourcefn at_reset(_caps: &X86PartitionCapabilities, _vp_info: &X86VpInfo) -> Self
fn at_reset(_caps: &X86PartitionCapabilities, _vp_info: &X86VpInfo) -> Self
Returns the value at VM reset.
Sourcefn can_compare(_caps: &X86PartitionCapabilities) -> bool
fn can_compare(_caps: &X86PartitionCapabilities) -> bool
Returns whether it’s possible to read this value and compare it to an
expected value. Read more
Sourceimpl<'encoding, AnyR: 'static> StructDecodeMetadata<'encoding, AnyR> for NestedState
impl<'encoding, AnyR: 'static> StructDecodeMetadata<'encoding, AnyR> for NestedState
Sourceimpl<AnyR: 'static> StructEncodeMetadata<AnyR> for NestedState
impl<AnyR: 'static> StructEncodeMetadata<AnyR> for NestedState
Sourceimpl StructMetadata for NestedState
impl StructMetadata for NestedState
impl Eq for NestedState
impl StructuralPartialEq for NestedState