TranslationRegisters

Struct TranslationRegisters 

pub struct TranslationRegisters {
    pub cpsr: Cpsr64,
    pub sctlr: SctlrEl1,
    pub tcr: TranslationControlEl1,
    pub ttbr0: u64,
    pub ttbr1: u64,
    pub syndrome: u64,
    pub encryption_mode: EncryptionMode,
}
Registers needed to walk the page table.

Fields

cpsr: Cpsr64

SPSR_EL2

sctlr: SctlrEl1

SCTLR_ELx

tcr: TranslationControlEl1

TCR_ELx

ttbr0: u64

TTBR0_ELx

ttbr1: u64

TTBR1_ELx

syndrome: u64

EsrEl2

encryption_mode: EncryptionMode

The way the processor uses to determine if an access is to encrypted memory. This is used to enforce that page tables and executable code are in encrypted memory.