pub struct QueueCompletion { /* private fields */ }Expand description
The minimal state required to publish a completion to the used ring.
This is everything complete_descriptor needs — notably not the payload
buffer descriptors, which are only used while the device is reading/writing
guest memory. Devices that must buffer completions (e.g. in-order
publication) can hold a QueueCompletion instead of a full
VirtioQueueCallbackWork to avoid retaining the payload.
Implementations
Sourceimpl QueueCompletion
impl QueueCompletion
pub fn descriptor_index(&self) -> u16