wait_for_used

Function wait_for_used 

pub async fn wait_for_used(
    driver: &DefaultDriver,
    interrupt_event: &Event,
    mem: &GuestMemory,
    used_addr: u64,
    queue_size: u16,
    used_idx: &mut u16,
) -> (u16, u32)
Wait for the next used ring entry, polling with a timeout.

interrupt_event is the event signaled by the device when it writes to the used ring. This function polls until read_used returns Some, panicking if 5 seconds elapse without an entry.