pub struct VirtioVsockVhostHandle {
pub vhost: OwnedFd,
pub guest_cid: u32,
}Expand description
A virtio-vsock device backed by the Linux kernel’s vhost_vsock
implementation.
Fields
vhost: OwnedFdA pre-opened /dev/vhost-vsock file descriptor.
The device resolver takes ownership and configures the vhost owner and guest CID.
guest_cid: u32The CID used to address the guest from the host’s AF_VSOCK
namespace.