RxReady

Enum RxReady 

pub enum RxReady {
    Connection(ConnectionInstanceId),
    PendingConnection(u64),
    SendReset(ConnectionKey),
}
Indicates a connection that is read to put data on the rx queue to send to the guest. N.B. When a future returns an item, it’s not always guaranteed that a packet is ready to be sent. It could be a spurious wake from a poll, or a pending connection that’s still reading its connect request, etc.

Variants



Connection(ConnectionInstanceId)

A connection has data or a control packet to send.



PendingConnection(u64)

A pending connection has data.



SendReset(ConnectionKey)

A RST packet should be sent for a connection that was removed or invalid.