pub enum ExternalDataError {
GpaRange(Error),
Access(AccessError),
WrongExternalDataType,
}Expand description
An error returned by read_external_ranges
Variants
GpaRange(Error)
The packet is corrupted in some way (e.g. it does not specify a reasonable set of GPA ranges).
Access(AccessError)
The packet specifies memory that this vmbus cannot read, for some reason.
WrongExternalDataType
Caller used read_external_ranges when the packet contains a buffer id,
and the caller should have called read_transfer_ranges