pub struct OpenRequest {
pub open_data: OpenData,
pub interrupt: Interrupt,
pub use_confidential_ring: bool,
pub use_confidential_external_memory: bool,
pub is_external_memory_pinned: bool,
}Expand description
Information provided to devices when a channel is opened.
Fields
open_data: OpenDataChannel open-specific data.
interrupt: InterruptThe interrupt used to signal the guest.
use_confidential_ring: boolIndicates if the currently connected vmbus client, as well as the channel the request is for, supports the use of confidential ring buffers.
use_confidential_external_memory: boolIndicates if the currently connected vmbus client, as well as the channel the request is for, supports the use of confidential external memory.
is_external_memory_pinned: boolIndicates if the currently connected vmbus client is expected to pin any external memory used by the channel. This is only true if the vmbus client supports GPA pinning and the channel indicated it requires pinned external memory. It can only be true for paravisor channels in a VM that supports the GPA pinning hypercalls.
Implementations