Server

Struct Server 

pub struct Server { /* private fields */ }
A struct modeling the server side of the VMBus control plane.

Implementations

Source

impl Server

pub fn save(&self) -> SavedState

Saves state.

Source

impl Server

pub fn new( vtl: Vtl, child_connection_id: u32, channel_id_offset: u16, use_absolute_channel_order: bool, ) -> Self

Creates a new VMBus server.

pub fn with_notifier<'a, T: Notifier>( &'a mut self, notifier: &'a mut T, ) -> ServerWithNotifier<'a, T>

Associates a Notifier with the server.

pub fn set_require_server_allocated_mnf(&mut self, require: bool)

Requires that the server allocates monitor pages. If this is enabled, the server will ignore guest-specified monitor pages and act as if none of the channels use MNF.

pub fn set_compatibility_version( &mut self, version: MaxVersionInfo, delay: bool, )

Sets a limit on the version and featuref flags that will be offered to the guest.

If delay is true, the limit will not apply to the first connection, but to all subsequent connections.

pub fn set_restore_compatibility_version(&mut self, version: MaxVersionInfo)

Indicates the maximum supported version when restoring from saved state. This is configured separately from Self::set_compatibility_version so that the restore-time limit can be configured independently of the limit used for live negotiation.

This allows features to be enabled for rollback scenarios while not yet enabling them for new connections.

pub fn channel_gpadls(&self, offer_id: OfferId) -> Vec<RestoredGpadl>

pub fn get_version(&self) -> Option<VersionInfo>

pub fn get_restore_open_params( &self, offer_id: OfferId, ) -> Result<OpenParams, RestoreError>

pub fn has_pending_messages(&self) -> bool

Check if there are any messages in the pending queue.

pub fn poll_flush_pending_messages( &mut self, send: impl FnMut(&OutgoingMessage) -> Poll<()>, ) -> Poll<()>

Tries to resend pending messages using the provided `send`` function.