pub fn byte_pipe(
driver: &(impl Driver + ?Sized),
file: File,
) -> Result<BytePipe<MappedRingMem>, Error>Expand description
Opens a byte pipe for the channel with a file from open_uio_device.
pub fn byte_pipe(
driver: &(impl Driver + ?Sized),
file: File,
) -> Result<BytePipe<MappedRingMem>, Error>Opens a byte pipe for the channel with a file from open_uio_device.