pub fn message_pipe(
driver: &(impl Driver + ?Sized),
file: File,
) -> Result<MessagePipe<MappedRingMem>, Error>Expand description
Opens a message pipe for the channel with a file from open_uio_device.
pub fn message_pipe(
driver: &(impl Driver + ?Sized),
file: File,
) -> Result<MessagePipe<MappedRingMem>, Error>Opens a message pipe for the channel with a file from open_uio_device.