VmTaskDriver

Struct VmTaskDriver 

pub struct VmTaskDriver { /* private fields */ }
A driver returned by VmTaskDriverSource.

This can be used to spawn tasks (via [Spawn]) and issue async IO (via [Driver]).

Implementations

Source

impl VmTaskDriver

pub fn retarget_vp(&self, target_vp: u32)

Updates the target VP for the task.

The effectiveness of this call, and when it would take effect, depends on the backend. For example, in the OpenHCL threadpool backend, this will cause new IO to target the new VP’s thread, but existing IO will continue to run on the original VP’s thread.

pub fn is_target_vp_ready(&self) -> bool

Returns whether the target VP is ready for tasks and IO.

A driver must be operable even if this is false, but the tasks and IO may run on a different target VP.

pub async fn wait_target_vp_ready(&self)

Waits for the target VP to be ready for tasks and IO.