pub struct ThreadDriverBackend { /* private fields */ }Expand description
A backend for VmTaskDriverSource based on
individual threads.
If no target VP is specified, this backend will spawn tasks and IO a default single-threaded IO driver. If a target VP is specified, the backend will spawn a separate thread and spawn tasks and IOs there.
Implementations