pub enum Error {
Show 27 variants
ReadDisk(StorageError),
WriteDisk(StorageError),
FlushDisk(StorageError),
FileInfoNotAllocated(FileId),
AllocateZero,
AllocateOffset,
InsufficientResources,
FileId,
WriteFileLength,
WriteFileBlocks,
Initialization(StorageError),
InvalidFormat(String),
CorruptFormat(String),
EmptyFile,
OverwriteEncrypted,
NeedsUnlock,
DecryptMetadataKey,
EncryptionNotSupported,
NotEncrypted,
DatastoreKeysFull,
NoActiveDatastoreKey,
V1Format,
OverwriteMove,
UnexpectedLength(&'static str, usize, usize),
InvalidArgument(&'static str),
OpenSSL(ErrorStack, &'static str),
Json(Error),
}Expand description
VMGS errors.
Variants
ReadDisk(StorageError)
Error reading from disk
WriteDisk(StorageError)
Error writing to disk
FlushDisk(StorageError)
Error flushing the disk
FileInfoNotAllocated(FileId)
The requested file ID is not allocated
AllocateZero
Cannot allocate 0 blocks
AllocateOffset
Invalid data allocation offsets
InsufficientResources
Insufficient resources
FileId
Invalid file ID
WriteFileLength
Invalid data buffer length
WriteFileBlocks
Trying to allocate too many blocks
Initialization(StorageError)
Fatal storage initialization error
InvalidFormat(String)
Invalid VMGS file format
CorruptFormat(String)
Corrupt VMGS file format
EmptyFile
The VMGS file has a non zero size but the contents are empty
OverwriteEncrypted
Cannot overwrite encrypted file with plaintext data
NeedsUnlock
File must be decrypted to perform this operation
DecryptMetadataKey
Failed to use the root key provided to decrypt VMGS metadata key
EncryptionNotSupported
VMGS file version does not support encryption
NotEncrypted
Cannot perform operation on unencrypted file
DatastoreKeysFull
There is no space to add a new encryption key
NoActiveDatastoreKey
Unable to determine inactive key for removal
V1Format
VMGS is v1 format
OverwriteMove
Cannot overwrite file when moving
UnexpectedLength(&'static str, usize, usize)
Unexpected data length
InvalidArgument(&'static str)
Invalid argument
OpenSSL(ErrorStack, &'static str)
OpenSSL error
Json(Error)
Serde JSON error