VmgsProvisioningMarker

Struct VmgsProvisioningMarker 

pub struct VmgsProvisioningMarker {
    pub provisioner: VmgsProvisioner,
    pub reason: VmgsProvisioningReason,
    pub tpm_version: String,
    pub tpm_nvram_size: usize,
    pub akcert_size: usize,
    pub akcert_attrs: String,
    pub provisioner_version: String,
}
Diagnostic marker that contains information about the VMGS’s provisioning. This marker is written once when a VMGS file is created, leaving a trace of where and how it originated (e.g., that it was created by OpenHCL). Adding new fields is safe, as it is not read by OpenHCL for any behavioral purpose.

Fields

provisioner: VmgsProvisionerreason: VmgsProvisioningReasontpm_version: Stringtpm_nvram_size: usizeakcert_size: usizeakcert_attrs: Stringprovisioner_version: String