#[repr(i32)]pub(crate) enum ExitCode {
Error = 1,
NotEncrypted = 2,
Empty = 3,
NotFound = 4,
V1Format = 5,
GspById = 6,
GspUnknown = 7,
}Expand description
Automation requires certain exit codes to be guaranteed main matches Error enum to ExitCode
- query-encryption must return NotEncrypted if file is not encrypted, GspById if the file contains a VMID, and GspUnknown if neither a VMID nor a key protector are present. Success indicates GspKey.
- dump-headers must return Empty when the file is blank.
- query-size must return NotFound when the file id is uninitialized.
- Error is returned for all other errors.
Variants