pub fn block_on_vp<F: Future>(
partition: Arc<dyn RequestYield>,
vp: VpIndex,
fut: F,
) -> F::OutputExpand description
Blocks on a future, where the future may run a VP (and so the associated waker needs to ask the VP to yield).
pub fn block_on_vp<F: Future>(
partition: Arc<dyn RequestYield>,
vp: VpIndex,
fut: F,
) -> F::OutputBlocks on a future, where the future may run a VP (and so the associated waker needs to ask the VP to yield).