pub struct BaseChipsetDeviceInterfaces {
pub framebuffer_local_control: Option<FramebufferLocalControl>,
}Expand description
A grab-bag of device-specific interfaces that may need to be wired up into upper-layer VMM specific code.
Fields may or may not be present, depending on what devices were
instantiated by the BaseChipsetBuilder
Fields
framebuffer_local_control: Option<FramebufferLocalControl>Auto Trait Implementations
impl Freeze for BaseChipsetDeviceInterfaces
impl !RefUnwindSafe for BaseChipsetDeviceInterfaces
impl Send for BaseChipsetDeviceInterfaces
impl Sync for BaseChipsetDeviceInterfaces
impl Unpin for BaseChipsetDeviceInterfaces
impl UnsafeUnpin for BaseChipsetDeviceInterfaces
impl !UnwindSafe for BaseChipsetDeviceInterfaces