is_canonical_address

Function is_canonical_address 

pub fn is_canonical_address(v: u64, bits: u32) -> bool
Returns true if v is a canonical linear address for a paging mode with bits effective virtual address bits (48 or 57): the top 64 - bits bits must be a sign-extension of the highest used bit.