TdKeyRequest

Struct TdKeyRequest 

#[repr(C)]
pub struct TdKeyRequest {
Show 14 fields pub key_name: u16, pub sw_key_name: u8, pub key_size: u8, pub _reserved0: [u8; 4], pub key_policy: TdxKeyPolicy, pub attributes_mask: u64, pub xfam_mask: u64, pub cpu_svn: [u8; 16], pub tee_tcb_svn: [u8; 16], pub isv_svn: u16, pub mr_config_svn: u16, pub mr_owner_config_svn: u16, pub salt: [u8; 32], pub _reserved1: [u8; 26],
}
Request structure (TDKEYREQUEST) that is passed as the input to the TDG.MR.KEY.GET TDCALL to derive a persistent key bound to the TD’s measurements and policy.

See TDKEYREQUEST, Table 2-1, “System Architecture Specification: Sealing Support for Intel TDX”, Revision 0.7, September 2025.

Fields

key_name: u16

KEYNAME - Identifies the key being requested. See TDX_KEY_NAME_SEAL.

sw_key_name: u8

SWKEYNAME - TD software-assigned key name/identifier.

key_size: u8

KEYSIZE - Requested key size. See TDX_KEY_SIZE_128 and TDX_KEY_SIZE_256.

_reserved0: [u8; 4]

Reserved.

key_policy: TdxKeyPolicy

KEYPOLICY - Selects which measurement and configuration registers are mixed into the derived key.

attributes_mask: u64

ATTRIBUTESMASK - Mask applied to TDCS.ATTRIBUTES before mixing into the key.

xfam_mask: u64

XFAMMASK - Mask applied to TDCS.XFAM before mixing into the key.

cpu_svn: [u8; 16]

CPUSVN

tee_tcb_svn: [u8; 16]

TEE_TCB_SVN

isv_svn: u16

ISVSVN

mr_config_svn: u16

MRCONFIGSVN

mr_owner_config_svn: u16

MROWNERCONFIGSVN

salt: [u8; 32]

SALT - Caller-supplied salt mixed into the derived key, allowing the same TD to derive multiple distinct keys.

_reserved1: [u8; 26]

Reserved.