pub struct LintCtx {
only_diffed: bool,
}Expand description
Context passed to each lint, containing configuration options.
Fields
only_diffed: boolWhen true we are linting a subset of repo files, so some lints may want to skip checks that require whole-repo analysis.