Lintable

Struct Lintable 

pub struct Lintable<T> {
    content: T,
    raw: Option<String>,
    fix: bool,
    path: PathBuf,
    workspace_dir: PathBuf,
    modified: bool,
    failed: AtomicBool,
}
A wrapper around file content for linting.

Most lints will want to use the Deref impl to access the content directly, but this also provides utilities for reporting errors and making fixes.

Fields

content: Traw: Option<String>fix: boolpath: PathBufworkspace_dir: PathBufmodified: boolfailed: AtomicBool

Implementations

Source

impl Lintable<String>

fn from_file( path: &Path, ctx: &FmtCtx, workspace_dir: &Path, ) -> Result<Option<Self>>

Read a text file into a Lintable<String>.

Returns None for binary (non-UTF-8) files.

Source

impl Lintable<DocumentMut>

fn from_file(path: &Path, ctx: &FmtCtx, workspace_dir: &Path) -> Result<Self>

Read a Cargo.toml file into a Lintable<DocumentMut>.

This can be from a crate or a workspace.

Source

impl<T> Lintable<T>

pub fn path(&self) -> &Path

Get the path of this file relative to the workspace root, for use in error messages.

pub fn raw(&self) -> Option<&str>

Get the original raw file content as a string, for lints that need to do their own parsing.

If the file content is already a string this will be None. This field is not modified when fixes are made.

pub fn fix(&mut self, description: &str, op: impl FnOnce(&mut T))

If fix is enabled, apply the given fix operation to the content and mark it modified. If fix is not enabled, report an error with the given description.

pub fn unfixable(&self, description: &str)

Report an error with the given description that cannot be automatically fixed.

fn finalize(self) -> Result<bool>
where T: Display,

If modified, write the content back to the file. Return whether any errors were reported.