pub struct UnusedDeps {
workspace_deps: BTreeSet<String>,
workspace_found_deps: BTreeSet<String>,
crate_deps: BTreeSet<String>,
crate_found_deps: BTreeSet<String>,
dep_matchers: BTreeMap<String, RegexMatcher>,
only_diffed: bool,
searcher: Searcher,
}Fields
workspace_deps: BTreeSet<String>All dependency names declared in the workspace.
workspace_found_deps: BTreeSet<String>Workspace dependencies for which a usage has been found so far in source files.
crate_deps: BTreeSet<String>All dependency names declared in the current crate.
crate_found_deps: BTreeSet<String>Dependencies for which a usage has been found so far in source files.
dep_matchers: BTreeMap<String, RegexMatcher>Pre-compiled regex matchers keyed by dependency name, built once for all workspace dependency names and extended lazily for any non-workspace deps encountered in individual crates.
only_diffed: boolWhether we are linting only diffed files (workspace-level check is unreliable in this mode because not all crates are visited).
searcher: SearcherPrebuilt grep searcher to avoid rebuilds