batch_files

Function batch_files 

fn batch_files(
    files: &[PathBuf],
    max_bytes: usize,
    max_files: usize,
) -> Vec<&[PathBuf]>
Split files into batches that fit in a command line and are small enough to spread across the available threads.