fn group_diffed(packages: &[Package], files: Vec<PathBuf>) -> Vec<Group>
Group diffed files by the edition of the innermost package containing them, so that they are parsed the same way as in a full run.