fn workspace_packages(sh: &XtaskShell) -> Result<Vec<Package>>Expand description
Collect the edition, directory, and crate roots of every workspace package.
fn workspace_packages(sh: &XtaskShell) -> Result<Vec<Package>>Collect the edition, directory, and crate roots of every workspace package.