FmtPass

Trait FmtPass 

pub trait FmtPass {
    // Required method
    fn run(self, ctx: FmtCtx) -> Result<()>;
}
Common trait implemented by all Fmt passes.

Required Methods

fn run(self, ctx: FmtCtx) -> Result<()>

Run the pass.

For consistency and simplicity, FmtPass implementations are allowed to assume that they are being run from the root of the repo’s filesystem.

Implementors