pub struct ByteEnabledDwordWrite { /* private fields */ }Expand description
A DWORD value with byte enables for PCI configuration space write.
Implementations
Sourceimpl ByteEnabledDwordWrite
impl ByteEnabledDwordWrite
Sourcepub const fn new(value: u32, byte_enable: PciConfigByteEnable) -> Self
pub const fn new(value: u32, byte_enable: PciConfigByteEnable) -> Self
Create a byte-enabled DWORD value.
Sourcepub const fn with_all_bytes_enabled(value: u32) -> Self
pub const fn with_all_bytes_enabled(value: u32) -> Self
Create a full-DWORD value with all byte lanes enabled.
Sourcepub fn from_intercept_buffer(
byte_enable: PciConfigByteEnable,
buffer: &[u8],
) -> Self
pub fn from_intercept_buffer( byte_enable: PciConfigByteEnable, buffer: &[u8], ) -> Self
Create a byte-enabled DWORD value from a slice of bytes.
Sourcepub fn as_valid_byte_slice(&self) -> &[u8] ⓘ
pub fn as_valid_byte_slice(&self) -> &[u8] ⓘ
Retrieve a mutable slice of the enabled byte lanes of the DWORD.
Sourcepub const fn byte_enable(&self) -> PciConfigByteEnable
pub const fn byte_enable(&self) -> PciConfigByteEnable
Retrieve the underlying byte enable.
Sourcepub const fn valid_mask(self) -> u32
pub const fn valid_mask(self) -> u32
Get the mask of valid bytes.
Sourcepub const fn merge(self, current_value: u32) -> u32
pub const fn merge(self, current_value: u32) -> u32
Merge enabled byte lanes from this value into current_value.
Sourcepub const fn merge_into(self, current_value: &mut u32)
pub const fn merge_into(self, current_value: &mut u32)
Merge enabled byte lanes from this value into current_value (read-modify-write).
Sourcepub const fn merge_low(self, current_value: u16) -> u16
pub const fn merge_low(self, current_value: u16) -> u16
Merge enabled byte lanes from the low WORD of this value into current_value.
Sourcepub const fn merge_high(self, current_value: u16) -> u16
pub const fn merge_high(self, current_value: u16) -> u16
Merge enabled byte lanes from the high WORD of this value into current_value.
Sourcepub const fn extract_low(self) -> u16
pub const fn extract_low(self) -> u16
Keep only enabled byte lanes from the low WORD this value.
Sourcepub const fn extract_high(self) -> u16
pub const fn extract_high(self) -> u16
Keep only enabled byte lanes from the high WORD this value.