pub struct PciConfigByteEnable(/* private fields */);Expand description
Byte enables for the four lanes of a PCI configuration DWORD.
Implementations
Sourceimpl PciConfigByteEnable
impl PciConfigByteEnable
Sourcepub const fn from_offset_len(offset: u16, len: usize) -> Result<Self, IoError>
pub const fn from_offset_len(offset: u16, len: usize) -> Result<Self, IoError>
Create byte enables for an access at offset with byte length len.
Sourcepub const fn to_byte_offset_len(self) -> (u16, usize)
pub const fn to_byte_offset_len(self) -> (u16, usize)
Returns the byte offset of the first enabled byte in the DWORD and the number of enabled bytes.
Sourcepub const fn merge(self, current_value: u32, write_value: u32) -> u32
pub const fn merge(self, current_value: u32, write_value: u32) -> u32
Merge enabled byte lanes from write_value into current_value.
Sourcepub const fn restrict(self, byte_enable: PciConfigByteEnable) -> Option<Self>
pub const fn restrict(self, byte_enable: PciConfigByteEnable) -> Option<Self>
Restrict the underlying byte enable to only include the provided bytes, or None when no bytes would be left enabled.
Sourcepub const fn exclude(self, byte_enable: PciConfigByteEnable) -> Option<Self>
pub const fn exclude(self, byte_enable: PciConfigByteEnable) -> Option<Self>
Exclude the provided bytes from the underlying byte enable, returning None when no bytes would be left enabled.