pub enum UnmapBehavior {
Unspecified,
Ignored,
Zeroes,
}Expand description
The behavior of the DiskIo::unmap operation.
This describes what happens to the content of unmapped sectors. Frontends
use this to report the correct behavior to the guest (e.g., SCSI
LBPRZ bit or NVMe DLFEAT field).
Variants
Unspecified
Unmap may or may not change the content, and not necessarily to zero. The guest cannot assume anything about the content of unmapped sectors.
Ignored
Unmaps are guaranteed to be ignored — the content is unchanged. The disk reports that unmap is not supported.
Zeroes
Unmap will deterministically zero the content. The guest can rely on reading back zeroes from unmapped sectors.