pub struct LazyRamDiskLayer { /* private fields */ }Expand description
A RAM-backed disk layer that infers unspecified topology parameters from the lower layer at attach time.
Implementations
Sourceimpl LazyRamDiskLayer
impl LazyRamDiskLayer
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new lazy RAM-backed disk layer.
By default, both size and sector size are inferred from the lower layer.
Use with_len and
with_sector_size to override.
Sourcepub fn with_len(self, len: u64) -> Self
pub fn with_len(self, len: u64) -> Self
Set the layer size in bytes.
If not set, the size is inferred from the lower layer at attach time.
Sourcepub fn with_sector_size(self, sector_size: u32) -> Self
pub fn with_sector_size(self, sector_size: u32) -> Self
Set the sector size in bytes.
If not set, the sector size is inferred from the lower layer at attach time, defaulting to 512 if there is no lower layer.