macro_rules! shell_cmd {
($rt:expr, $cmd:literal) => { ... };
}Expand description
Construct a command to run via the flowey shell.
This is a wrapper around [xshell::cmd!] that returns a FloweyCmd
instead of a raw [xshell::Cmd]. The FloweyCmd applies any
CommandWrapperKind configured on the shell at execution time, making it
possible to transparently wrap commands (e.g. in nix-shell --pure)
without touching every callsite.
Example
ⓘ
flowey::shell_cmd!(rt, "cargo build --release").run()?;