pub struct BuildReproducibleCli {
pub recipe: ReproducibleOpenHclRecipe,
pub release: bool,
}Expand description
Build reproducible artifacts locally. DO NOT USE IN CI.
Fields
recipe: ReproducibleOpenHclRecipeSpecify which OpenHCL recipe to build / customize off-of.
A “recipe” corresponds to the various standard IGVM SKUs that are actively supported and tested in our build infrastructure.
It encodes all the details of what goes into an individual IGVM file,
such as what build flags openvmm_hcl should be built with, what goes
into a VTL2 initrd, what igvmfilegen manifest is being used, etc…
release: boolBuild using release variants of all constituent binary components.
Uses –profile=boot-release for openhcl_boot, –profile=openhcl-ship when building openvmm_hcl, etc…