pub struct CcaTestsCli {
pub test_root: PathBuf,
pub install_emu: bool,
pub update_emu: bool,
pub verbose: bool,
pub update_emu_subcmds: CcaTestsUpdateEmuSubCmds,
}Expand description
CCA test flows, including installing, updating CCA emulation environment and run OpenVMM tests
Fields
test_root: PathBufRoot directory for holding all CCA test related stuff
install_emu: boolInstall CCA emulation environment, including downloading emulator and building all needed firmware
update_emu: boolUpdate CCA emulation environment by rebuilding firmwares, support a few sub-commands
verbose: boolVerbose pipeline output
update_emu_subcmds: CcaTestsUpdateEmuSubCmdsTrait Implementations
Sourceimpl Args for CcaTestsCli
impl Args for CcaTestsCli
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
Report the [
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to [
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl FromArgMatches for CcaTestsCli
impl FromArgMatches for CcaTestsCli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl IntoPipeline for CcaTestsCli
impl IntoPipeline for CcaTestsCli
fn into_pipeline(self, backend_hint: PipelineBackendHint) -> Result<Pipeline>