pub struct MapFile {
isolation: LoaderIsolationType,
required_memory: Vec<RequiredMemory>,
accepted_ranges: Vec<(MemoryRange, RangeInfo)>,
relocatable_regions: Vec<(MemoryRange, RelocationType)>,
reported_ranges: Vec<(MemoryRange, String)>,
}Expand description
A map file representing information about a given generated IGVM file from a loader.
This can be used to save additional information about the layout of the address space that importing an IGVM file will create.
Fields
isolation: LoaderIsolationTyperequired_memory: Vec<RequiredMemory>accepted_ranges: Vec<(MemoryRange, RangeInfo)>relocatable_regions: Vec<(MemoryRange, RelocationType)>reported_ranges: Vec<(MemoryRange, String)>Implementations
Sourceimpl MapFile
impl MapFile
Sourcepub fn report_range(&mut self, range: MemoryRange, tag: impl Into<String>)
pub fn report_range(&mut self, range: MemoryRange, tag: impl Into<String>)
Adds a map-only annotation for a range that is not represented by an IGVM directive.
Reported ranges appear under IGVM file reported ranges in tracing and
the written map file. They do not change the generated IGVM file.
Sourcepub fn emit_tracing(&self)
pub fn emit_tracing(&self)
Emit this map file information to tracing::info.