pub struct HardwareConfigFaultConfig {
pub vendor_id: Option<u16>,
pub device_id: Option<u16>,
}Expand description
A fault configuration for overriding the device’s hardware configuration (i.e. the values reported in PCI configuration space).
When a field is Some, its value replaces the corresponding field reported
by the NVMe fault controller’s PCI hardware IDs. When None, the real
hardware ID value is used unchanged. Unlike most other faults in this
module, hardware config faults are applied at device construction time
and are therefore not gated by the fault_active flag.
Example
Override the Vendor ID and Device ID reported in PCI config space.
use mesh::CellUpdater;
use nvme_resources::fault::FaultConfiguration;
use nvme_resources::fault::HardwareConfigFaultConfig;
pub fn hardware_config_fault() -> FaultConfiguration {
let mut fault_start_updater = CellUpdater::new(false);
FaultConfiguration::new(fault_start_updater.cell())
.with_hardware_config_fault(
HardwareConfigFaultConfig::new()
.with_vendor_id(0x1414)
.with_device_id(0xc03e),
)
}Fields
vendor_id: Option<u16>Override for the device’s PCI Vendor ID. When None, the real Vendor
ID is used.
device_id: Option<u16>Override for the device’s PCI Device ID. When None, the real Device
ID is used.
Implementations
Sourceimpl HardwareConfigFaultConfig
impl HardwareConfigFaultConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new no-op hardware config fault configuration. All fields
default to None, meaning the real hardware values are used.
Sourcepub fn with_vendor_id(self, vendor_id: u16) -> Self
pub fn with_vendor_id(self, vendor_id: u16) -> Self
Override the PCI Vendor ID reported by the device.
Sourcepub fn with_device_id(self, device_id: u16) -> Self
pub fn with_device_id(self, device_id: u16) -> Self
Override the PCI Device ID reported by the device.