pub struct LidSupportedAndEffects(/* private fields */);Expand description
LID Supported and Effects Data Structure, one per LID in the Supported Log Pages log page (LID 00h). See NVMe Base 2.3 Figure 208.
Implementations
Sourceimpl LidSupportedAndEffects
impl LidSupportedAndEffects
Sourcepub const fn with_lsupp_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_lsupp_checked(self, value: bool) -> Result<Self, ()>
LID Supported
Bits: 0..1
Sourcepub const fn with_lsupp(self, value: bool) -> Self
pub const fn with_lsupp(self, value: bool) -> Self
LID Supported
Bits: 0..1
Sourcepub const fn set_lsupp_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_lsupp_checked(&mut self, value: bool) -> Result<(), ()>
LID Supported
Bits: 0..1
Sourcepub const fn with_ios_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_ios_checked(self, value: bool) -> Result<Self, ()>
Index Offset Supported
Bits: 1..2
Sourcepub const fn set_ios_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_ios_checked(&mut self, value: bool) -> Result<(), ()>
Index Offset Supported
Bits: 1..2
Sourcepub const fn with_lidsp_checked(self, value: u16) -> Result<Self, ()>
pub const fn with_lidsp_checked(self, value: u16) -> Result<Self, ()>
LID Specific Parameter
Bits: 16..32
Sourcepub const fn with_lidsp(self, value: u16) -> Self
pub const fn with_lidsp(self, value: u16) -> Self
LID Specific Parameter
Bits: 16..32