pub async fn open_disk_type(
path: &Path,
options: OpenDiskOptions,
) -> Result<Resource<DiskHandleKind>>Expand description
Opens the resources needed for using a disk from a file at path.
If the file ends with .vhd and is a fixed VHD1, it will be opened using the user-mode VHD parser. Otherwise, if the file ends with .vhd, the file will be opened using the kernel-mode VHD parser (Windows only).
If the file ends with .vhdx, the kernel-mode VHD parser is used on Windows. On Linux, the pure-Rust VHDX parser is used, with automatic parent-locator walking for differencing chains.