pub struct PolledChild<C> { /* private fields */ }Expand description
An owned child process with an asynchronous exit wait.
The wait field is declared before child so that the backend wait
registration is dropped before the child’s underlying handle or fd.
Implementations
Sourceimpl<C> PolledChild<C>
impl<C> PolledChild<C>
Sourceimpl PolledChild<Child>
impl PolledChild<Child>