#[repr(transparent)]pub struct LinkWidth(pub u32);Expand description
PCIe Link Width encoding values for use in Link Capabilities and other registers.
Values are defined in PCIe Base Specification for the Max Link Width field in Link Capabilities Register and similar fields.
Tuple Fields
0: u32Implementations