pub struct BistHeader(/* private fields */);Expand description
The BIST / Header Type / Latency Timer / Cache Line Size DWORD at config space offset 0x0C.
| Bits 31-24 | Bits 23-16 | Bits 15-8 | Bits 7-0 |
|---|---|---|---|
| BIST | Header Type | Latency Timer | Cache Line Size |
Implementations
Sourceimpl BistHeader
impl BistHeader
Sourcepub const fn cache_line_size(&self) -> u8
pub const fn cache_line_size(&self) -> u8
Bits: 0..8
Sourcepub const fn with_cache_line_size_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_cache_line_size_checked(self, value: u8) -> Result<Self, ()>
Bits: 0..8
Sourcepub const fn with_cache_line_size(self, value: u8) -> Self
pub const fn with_cache_line_size(self, value: u8) -> Self
Bits: 0..8
Sourcepub const fn set_cache_line_size(&mut self, value: u8)
pub const fn set_cache_line_size(&mut self, value: u8)
Bits: 0..8
Sourcepub const fn latency_timer(&self) -> u8
pub const fn latency_timer(&self) -> u8
Bits: 8..16
Sourcepub const fn with_latency_timer_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_latency_timer_checked(self, value: u8) -> Result<Self, ()>
Bits: 8..16
Sourcepub const fn with_latency_timer(self, value: u8) -> Self
pub const fn with_latency_timer(self, value: u8) -> Self
Bits: 8..16
Sourcepub const fn set_latency_timer(&mut self, value: u8)
pub const fn set_latency_timer(&mut self, value: u8)
Bits: 8..16
Sourcepub const fn header_type(&self) -> u8
pub const fn header_type(&self) -> u8
Header layout type (0 = standard, 1 = PCI-to-PCI bridge).
Bits: 16..23
Sourcepub const fn with_header_type_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_header_type_checked(self, value: u8) -> Result<Self, ()>
Header layout type (0 = standard, 1 = PCI-to-PCI bridge).
Bits: 16..23
Sourcepub const fn with_header_type(self, value: u8) -> Self
pub const fn with_header_type(self, value: u8) -> Self
Header layout type (0 = standard, 1 = PCI-to-PCI bridge).
Bits: 16..23
Sourcepub const fn set_header_type(&mut self, value: u8)
pub const fn set_header_type(&mut self, value: u8)
Header layout type (0 = standard, 1 = PCI-to-PCI bridge).
Bits: 16..23
Sourcepub const fn set_header_type_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_header_type_checked(&mut self, value: u8) -> Result<(), ()>
Header layout type (0 = standard, 1 = PCI-to-PCI bridge).
Bits: 16..23
Sourcepub const fn multi_function(&self) -> bool
pub const fn multi_function(&self) -> bool
When set, the device is part of a multi-function package.
Bits: 23..24
Sourcepub const fn with_multi_function_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_multi_function_checked(self, value: bool) -> Result<Self, ()>
When set, the device is part of a multi-function package.
Bits: 23..24
Sourcepub const fn with_multi_function(self, value: bool) -> Self
pub const fn with_multi_function(self, value: bool) -> Self
When set, the device is part of a multi-function package.
Bits: 23..24
Sourcepub const fn set_multi_function(&mut self, value: bool)
pub const fn set_multi_function(&mut self, value: bool)
When set, the device is part of a multi-function package.
Bits: 23..24
Sourcepub const fn set_multi_function_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_multi_function_checked( &mut self, value: bool, ) -> Result<(), ()>
When set, the device is part of a multi-function package.
Bits: 23..24
Sourcepub const fn with_bist_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_bist_checked(self, value: u8) -> Result<Self, ()>
Bits: 24..32