macro_rules! unstable_test_sync {
($f:ident, $req:expr, $reason:expr) => { ... };
}Expand description
Defines a single unstable test named after the synchronous run function
$f, using $req to resolve its artifacts.
$reason documents why the test is unstable and is logged when an unstable
failure is ignored.