pub fn ensure_2mb_hugetlb_pages(required_pages: u64) -> Result<bool>Expand description
Returns whether the host appears to have enough 2 MiB hugetlb pages available.
By default, missing or insufficient host support returns Ok(false) after
logging a clear warning so local developer runs can skip tests cleanly. If
OPENVMM_REQUIRE_2MB_HUGETLB is set, missing or insufficient host support is
an error.