fn pid1_reap_loop(pipette_pid: i32) -> !Expand description
PID 1 reap loop: wait for children forever.
Under normal operation, pipette does not exit — the host tears down the VM directly. If the pipette child does exit unexpectedly, we panic, which will cause the kernel to panic and the VMM to observe a triple fault.