pub trait UefiSecurityPolicywhere
Self: UefiSecurityPolicyParams,{
// Provided method
fn validate_secure_boot_enabled(&self, on: bool) -> Result<()> { ... }
}Expand description
A trait for validating UEFI security settings. Implementors only
need to provide UefiSecurityPolicyParams; all methods here have
default bodies, so policies can use an empty marker impl.
Provided Methods
Sourcefn validate_secure_boot_enabled(&self, on: bool) -> Result<()>
fn validate_secure_boot_enabled(&self, on: bool) -> Result<()>
Validate that secure boot is enabled if required by the policy.