pub fn alloc_shared_memory_hugetlb(
size: usize,
name: &str,
hugepage_size: Option<usize>,
_numa_node: Option<u32>,
) -> Result<OwnedFd>Expand description
Allocates a hugetlb mappable shared memory object of size bytes.
If hugepage_size is specified, it is encoded in the memfd flags using
the Linux MFD_HUGE_* convention.