pub struct TdispTdiReportMmioFlags(/* private fields */);Expand description
PCI Express Base Specification Revision 6.3 Section 11.3.11 DEVICE_INTERFACE_REPORT
Implementations
Sourceimpl TdispTdiReportMmioFlags
impl TdispTdiReportMmioFlags
Sourcepub const fn range_maps_msix_table(&self) -> bool
pub const fn range_maps_msix_table(&self) -> bool
MSI-X Table – if the range maps MSI-X table. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 0..1
Sourcepub const fn with_range_maps_msix_table_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_range_maps_msix_table_checked( self, value: bool, ) -> Result<Self, ()>
MSI-X Table – if the range maps MSI-X table. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 0..1
Sourcepub const fn with_range_maps_msix_table(self, value: bool) -> Self
pub const fn with_range_maps_msix_table(self, value: bool) -> Self
MSI-X Table – if the range maps MSI-X table. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 0..1
Sourcepub const fn set_range_maps_msix_table(&mut self, value: bool)
pub const fn set_range_maps_msix_table(&mut self, value: bool)
MSI-X Table – if the range maps MSI-X table. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 0..1
Sourcepub const fn set_range_maps_msix_table_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_range_maps_msix_table_checked( &mut self, value: bool, ) -> Result<(), ()>
MSI-X Table – if the range maps MSI-X table. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 0..1
Sourcepub const fn range_maps_msix_pba(&self) -> bool
pub const fn range_maps_msix_pba(&self) -> bool
MSI-X PBA – if the range maps MSI-X PBA. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 1..2
Sourcepub const fn with_range_maps_msix_pba_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_range_maps_msix_pba_checked( self, value: bool, ) -> Result<Self, ()>
MSI-X PBA – if the range maps MSI-X PBA. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 1..2
Sourcepub const fn with_range_maps_msix_pba(self, value: bool) -> Self
pub const fn with_range_maps_msix_pba(self, value: bool) -> Self
MSI-X PBA – if the range maps MSI-X PBA. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 1..2
Sourcepub const fn set_range_maps_msix_pba(&mut self, value: bool)
pub const fn set_range_maps_msix_pba(&mut self, value: bool)
MSI-X PBA – if the range maps MSI-X PBA. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 1..2
Sourcepub const fn set_range_maps_msix_pba_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_range_maps_msix_pba_checked( &mut self, value: bool, ) -> Result<(), ()>
MSI-X PBA – if the range maps MSI-X PBA. This must be reported only if locked by the LOCK_INTERFACE_REQUEST.
Bits: 1..2
Sourcepub const fn is_non_tee_mem(&self) -> bool
pub const fn is_non_tee_mem(&self) -> bool
IS_NON_TEE_MEM – must be 1b if the range is non-TEE memory. For attribute updatable ranges (see below), this field must indicate attribute of the range when the TDI was locked.
Bits: 2..3
Sourcepub const fn with_is_non_tee_mem_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_is_non_tee_mem_checked(self, value: bool) -> Result<Self, ()>
IS_NON_TEE_MEM – must be 1b if the range is non-TEE memory. For attribute updatable ranges (see below), this field must indicate attribute of the range when the TDI was locked.
Bits: 2..3
Sourcepub const fn with_is_non_tee_mem(self, value: bool) -> Self
pub const fn with_is_non_tee_mem(self, value: bool) -> Self
IS_NON_TEE_MEM – must be 1b if the range is non-TEE memory. For attribute updatable ranges (see below), this field must indicate attribute of the range when the TDI was locked.
Bits: 2..3
Sourcepub const fn set_is_non_tee_mem(&mut self, value: bool)
pub const fn set_is_non_tee_mem(&mut self, value: bool)
IS_NON_TEE_MEM – must be 1b if the range is non-TEE memory. For attribute updatable ranges (see below), this field must indicate attribute of the range when the TDI was locked.
Bits: 2..3
Sourcepub const fn set_is_non_tee_mem_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_is_non_tee_mem_checked( &mut self, value: bool, ) -> Result<(), ()>
IS_NON_TEE_MEM – must be 1b if the range is non-TEE memory. For attribute updatable ranges (see below), this field must indicate attribute of the range when the TDI was locked.
Bits: 2..3
Sourcepub const fn is_mem_attr_updatable(&self) -> bool
pub const fn is_mem_attr_updatable(&self) -> bool
IS_MEM_ATTR_UPDATABLE – must be 1b if the attributes of this range is updatable using SET_MMIO_ATTRIBUTE_REQUEST
Bits: 3..4
Sourcepub const fn with_is_mem_attr_updatable_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_is_mem_attr_updatable_checked( self, value: bool, ) -> Result<Self, ()>
IS_MEM_ATTR_UPDATABLE – must be 1b if the attributes of this range is updatable using SET_MMIO_ATTRIBUTE_REQUEST
Bits: 3..4
Sourcepub const fn with_is_mem_attr_updatable(self, value: bool) -> Self
pub const fn with_is_mem_attr_updatable(self, value: bool) -> Self
IS_MEM_ATTR_UPDATABLE – must be 1b if the attributes of this range is updatable using SET_MMIO_ATTRIBUTE_REQUEST
Bits: 3..4
Sourcepub const fn set_is_mem_attr_updatable(&mut self, value: bool)
pub const fn set_is_mem_attr_updatable(&mut self, value: bool)
IS_MEM_ATTR_UPDATABLE – must be 1b if the attributes of this range is updatable using SET_MMIO_ATTRIBUTE_REQUEST
Bits: 3..4