Enum TdispGuestProtocolType
#[repr(i32)]pub enum TdispGuestProtocolType {
Invalid = 0,
AmdSevTioV1 = 1,
IntelTdxConnectV1 = 2,
}Expand description
Represents the type of CVM technology the guest requests to use. As new features are added by respective OEMs, this enum will be extended if these protocols change.
The host is responsible for accepting the guest’s request and providing the appropriate guest-to-host interface. Hosts must support downlevel guest requests to ensure that older guests can be supported.
Variants
Invalid = 0
Invalid guest protocol type.
AmdSevTioV1 = 1
Guest is utilizing OpenHCL’s V1 TDISP interface for AMD® SEV-TIO
IntelTdxConnectV1 = 2
Guest is utilizing OpenHCL’s V1 TDISP interface for Intel® TDX Connect
Implementations
impl TdispGuestProtocolType
impl TdispGuestProtocolType
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<TdispGuestProtocolType>
pub fn from_str_name(value: &str) -> Option<TdispGuestProtocolType>
Creates an enum from field names used in the ProtoBuf definition.