Enum TdispTdiState
#[repr(i32)]pub enum TdispTdiState {
Uninitialized = 0,
Unlocked = 1,
Locked = 2,
Run = 3,
}Expand description
Represents the state of the TDISP host device emulator.
Variants
Uninitialized = 0
The TDISP state is not initialized or indeterminate.
Unlocked = 1
TDI.Unlocked - The device is in its default “reset” state. Resources can be configured and no functionality can be used. Attestation cannot take place until the device has been locked.
Locked = 2
TDI.Locked - The device resources have been locked and attestation can take place. The device’s resources have been mapped and configured in hardware, but the device has not been attested. Private DMA and MMIO will not be functional until the resources have been accepted into the guest context. Unencrypted “bounced” operations are still allowed.
Run = 3
TDI.Run - The device is no longer functional for unencrypted operations. Device resources are locked but encrypted operations might not yet be functional. The device will not be functional for encrypted operations until it has been fully validated by the guest calling to firmware to accept resources.
Implementations
impl TdispTdiState
impl TdispTdiState
impl TdispTdiState
impl TdispTdiState
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<TdispTdiState>
pub fn from_str_name(value: &str) -> Option<TdispTdiState>
Creates an enum from field names used in the ProtoBuf definition.