pub enum TdispUnbindReason {
Unknown(Error),
GuestInitiated(TdispGuestUnbindReason),
ImpossibleStateTransition(Error),
InvalidGuestTransitionToLocked,
InvalidGuestTransitionToRun,
InvalidGuestGetAttestationReportState,
InvalidGuestAcceptAttestationReportState,
InvalidGuestUnbindReason(Error),
}Expand description
The reason for an Unbind call. This can be guest or host initiated.
Unbind can be called any time during the assignment flow.
This is used for telemetry and debugging.
Variants
Unknown(Error)
Unknown reason.
GuestInitiated(TdispGuestUnbindReason)
The device was unbound manually by the guest or host for a non-error reason.
ImpossibleStateTransition(Error)
The device attempted to perform an invalid state transition.
InvalidGuestTransitionToLocked
The guest tried to transition the device to the Locked state while the device was not in the Unlocked state.
InvalidGuestTransitionToRun
The guest tried to transition the device to the Run state while the device was not in the Locked state.
InvalidGuestGetAttestationReportState
The guest tried to retrieve the attestation report while the device was not in the Locked or Run state.
InvalidGuestAcceptAttestationReportState
The guest tried to accept the attestation report while the device was not in the Locked or Run state.
InvalidGuestUnbindReason(Error)
The guest tried to unbind the device while the device with an unbind reason that is not recognized as a valid guest unbind reason. The unbind still succeeds but the recorded reason is discarded.