pub struct TdispHostStateMachine { /* private fields */ }Expand description
The state machine for the TDISP assignment flow for a device on the host. Both the guest and host synchronize this state machine with each other as they move through the assignment flow.
Implementations
Sourceimpl TdispHostStateMachine
impl TdispHostStateMachine
Sourcepub fn new(host_interface: Arc<Mutex<dyn TdispHostDeviceInterface>>) -> Self
pub fn new(host_interface: Arc<Mutex<dyn TdispHostDeviceInterface>>) -> Self
Create a new TDISP state machine with the Unlocked state.
Sourcepub fn set_debug_device_id(&mut self, debug_device_id: String)
pub fn set_debug_device_id(&mut self, debug_device_id: String)
Set the debug device ID string.