pub trait ResetPartition {
type Error: Error;
// Required method
fn reset(&self) -> Result<(), Self::Error>;
}Expand description
Extension trait for resetting the partition.
Required Associated Types
Required Methods
Sourcefn reset(&self) -> Result<(), Self::Error>
fn reset(&self) -> Result<(), Self::Error>
Resets the partition, restoring all partition state to the initial state.
The caller must ensure that no VPs are running when this is called.
This resets partition-level (VM-wide) state. After this completes,
the caller dispatches Processor::reset to each VP’s thread to
reset per-VP state (registers, APIC, synic message queues, etc.).
If this fails, the partition is in a bad state and cannot be resumed until a subsequent reset call succeeds.