pub struct TranslationRegisters {
pub cpsr: Cpsr64,
pub sctlr: SctlrEl1,
pub tcr: TranslationControlEl1,
pub ttbr0: u64,
pub ttbr1: u64,
pub syndrome: u64,
pub encryption_mode: EncryptionMode,
}Expand description
Registers needed to walk the page table.
Fields
cpsr: Cpsr64SPSR_EL2
sctlr: SctlrEl1SCTLR_ELx
tcr: TranslationControlEl1TCR_ELx
ttbr0: u64TTBR0_ELx
ttbr1: u64TTBR1_ELx
syndrome: u64EsrEl2
encryption_mode: EncryptionModeThe way the processor uses to determine if an access is to encrypted memory. This is used to enforce that page tables and executable code are in encrypted memory.