pub struct EventProxy { /* private fields */ }Expand description
An async task that bridges an [Event] to an Interrupt.
When the interrupt is not directly backed by an OS event (e.g., it uses
a function callback for MSI-X), this wrapper creates a new event and
spawns a task that waits on it and calls Interrupt::deliver. When
the EventProxy is dropped, the task is cancelled.
Implementations