pub struct Interrupt { /* private fields */ }Expand description
An object representing an interrupt-like signal to notify the guest of device activity.
This is generally an edge-triggered interrupt, but it could also be a synic event or similar notification.
The interrupt can be backed by a [pal_event::Event] or a function. In the
former case, the Interrupt can be sent across a mesh channel to remote
processes.
Implementations
Sourceimpl Interrupt
impl Interrupt
Sourcepub fn null() -> Self
pub fn null() -> Self
An interrupt that does nothing.
Note that Self::event will still return a valid event, which will be
lazily created on demand. This allows the interrupt to be used with APIs
that require an event, without actually delivering any notifications.
Sourcepub fn from_event(event: Event) -> Self
pub fn from_event(event: Event) -> Self
Creates an interrupt from an event.
The event will be signaled when Self::deliver is called.
Sourcepub fn from_fn<F>(f: F) -> Self
pub fn from_fn<F>(f: F) -> Self
Creates an interrupt from a function.
The function will be called when Self::deliver is called. This type of
interrupt cannot be sent to a remote process.
Sourcepub fn from_target(target: impl InterruptTarget + 'static) -> Self
pub fn from_target(target: impl InterruptTarget + 'static) -> Self
Creates an interrupt from an InterruptTarget implementation.
Sourcepub fn event(&self) -> Option<&Event>
pub fn event(&self) -> Option<&Event>
Gets a reference to the backing event, if there is one.
This will attempt to lazily create the event via the target if one has not already been cached.
Sourcepub fn event_or_proxy(
&self,
driver: &impl SpawnDriver,
) -> Result<(Event, Option<EventProxy>)>
pub fn event_or_proxy( &self, driver: &impl SpawnDriver, ) -> Result<(Event, Option<EventProxy>)>
Returns an event that, when signaled, will deliver this interrupt.
If Self::event returns an event, returns a clone of it and no
proxy is needed. Otherwise, creates an EventProxy that spawns an
async task to bridge a new event to Interrupt::deliver. The caller
must keep the returned Option<EventProxy> alive for as long as the
event is in use.